/*********************************************
 * 
 * Copyright (C) 1990-2014 by IBM.
 *  All Rights Reserved.
 *
 *  N O T I C E
 *
 *  THIS MATERIAL IS CONSIDERED A TRADE SECRET BY IBM.
 *  UNAUTHORIZED ACCESS, USE, REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * *********************************************
 * 
 * 
 * IMPORTANT:
 * =========
 * This code is part of ARMOR3 Research Asset. It cannot be copied for any other use
 * except ARMOR3 project
 * Please contact ARMOR3 Team for any questions
 *
 *
 * 
 * OPL 12.6 Model
 * Author: Abhishek Raman
 *********************************************/

// INPUT DATA =====================================================================================
	tuple T_PS_Execution_Objective {
	  	int Scenario_Id;
	  	int Objective_Id;
	  	//int Problem_Status;
	}; 
	{T_PS_Execution_Objective} ST_PS_Execution_Objective = ...; 
	
	tuple T_PS_Execution_Parameters { 
		int Scenario_Id;
		int Analysis_Duration;
		int Time_Bucket;
		int Analysis_Year;
	};
	{T_PS_Execution_Parameters} ST_PS_Execution_Parameters = ...; 
	
	tuple T_PS_Budget_Parameters {
	  	int Scenario_Id;
  		int Time;
	  	int Budget;
	  	float Age_Percentage;
	};
	{T_PS_Budget_Parameters} ST_PS_Budget_Parameters = ...;
	
	tuple T_PS_Budget_Percentage_Parameters {
	  	int Scenario_Id;
	  	int Time;
	  	int Treatment_Id;
	  	string Treatment_Name;
	  	float Percentage;
	  	string Include_Exclude;
	};
	{T_PS_Budget_Percentage_Parameters} ST_PS_Budget_Percentage_Parameters = ...;
	
	tuple T_PS_Asset_Factor {
	  	string Asset_Id;
	  	int Factor_Id;
	  	string Factor_Value;
	  	int Time;
	};
	{T_PS_Asset_Factor} ST_PS_Asset_Factor 	= ...;
	
	tuple T_PS_Factor {
	  	int Factor_Id;
	  	string Factor_Name; 
	  	string Factor_Description;
	};
	{T_PS_Factor} ST_PS_Factor 	= ...; 
	
	tuple T_PS_Asset_Prescription {
		int Scenario_Id;
		string Asset_Id;
		int Driver_Id;
		int Treatment_Id;
		float Treatment_Cost;
		int Service_Life_Extension;
		int Service_Life_Improvement;
		string Location_Description;
		int Time;
		}; 
	{T_PS_Asset_Prescription} ST_PS_Asset_Prescription 	= ...;	
	
	tuple T_PS_Factor_Id_Age { 
		int factor_id;
	};
	{T_PS_Factor_Id_Age} ST_PS_Factor_Id_Age = ...;	
	
	tuple T_PS_Factor_Id_Length { 
		int factor_id;
	};
	{T_PS_Factor_Id_Length} ST_PS_Factor_Id_Length = ...;
// ================================================================================================


// INTERNAL DATA ==================================================================================
	int P_numObj = 2;
	int P_objON[1..P_numObj] = [	
		i
		: 
		1 
		| 
		i in 1..P_numObj,
		o in ST_PS_Execution_Objective
		: 
		o.Objective_Id==i
	];
	 
	int P_fromYear = min(ep in ST_PS_Execution_Parameters) ep.Analysis_Year;
	int P_toYear = P_fromYear + min(ep in ST_PS_Execution_Parameters) ep.Analysis_Duration;	
	int P_scenarioId = min(ep in ST_PS_Execution_Parameters) ep.Scenario_Id;
	int P_assetAgeFactorIndex = min(fi in ST_PS_Factor_Id_Age) fi.factor_id; //2;
	int P_assetLengthFactorIndex = min(fi in ST_PS_Factor_Id_Length) fi.factor_id; //9;
								
	{T_PS_Asset_Prescription} ST_PS_Asset_PrescriptionP = {
	  	ap 
	  	| 
	  	ap in ST_PS_Asset_Prescription 
		: 
		ap.Time >= P_fromYear 
		&& ap.Time <= P_toYear
	};
									
	sorted {int} S_Planning_Horizon 
		= {ap.Time | ap in ST_PS_Asset_PrescriptionP}; 
	
	{string} S_Asset_Id = {ap.Asset_Id | ap in ST_PS_Asset_Prescription}; 
	{int} S_Treatment_Id = {ap.Treatment_Id | ap in ST_PS_Asset_Prescription};
	float P_totalTreatmentCost = sum(ap in ST_PS_Asset_PrescriptionP) ap.Treatment_Cost;
									
	int P_assetAge[S_Asset_Id] 							
		= [	a : intValue(af.Factor_Value) 
			| 
			a in S_Asset_Id, 
			af in ST_PS_Asset_Factor 
			: 
			a==af.Asset_Id 
			&& af.Factor_Id==P_assetAgeFactorIndex
		];
	
	float P_assetLength[S_Asset_Id] 							
				= [	a : floatValue(af.Factor_Value) 
					| 
					a in S_Asset_Id, 
					af in ST_PS_Asset_Factor
					: 
					a==af.Asset_Id 
					&& P_assetLengthFactorIndex != 0
					&& af.Factor_Id==P_assetLengthFactorIndex
		];
	
	//if no length property for current asset class, use 1 as default length 
	execute {
		if(P_assetLengthFactorIndex == "0"){
			for (var asset_id in S_Asset_Id){
				P_assetLength[asset_id] = Opl.floatValue("1");
			}
		}
	}
	
	float P_assetAgeLengthByYear[S_Asset_Id][S_Planning_Horizon]
	  	= [ a: [t:  P_assetLength[a]*(P_assetAge[a] + t - P_fromYear) ] 
	  		| 
	  		a in S_Asset_Id,
	  		t in S_Planning_Horizon
	  	]; 
	
	float P_avgAgeByYear[S_Planning_Horizon] 
		= [	t : (sum(a in S_Asset_Id) P_assetAgeLengthByYear[a][t]) / (sum(a in S_Asset_Id) P_assetLength[a])
			| t in S_Planning_Horizon
		];
									
	float P_BudgetPrcByTreatment[S_Treatment_Id][S_Planning_Horizon] 		
		= [tr: [t : bpp.Percentage]
			| 
			tr in S_Treatment_Id, 
			t in S_Planning_Horizon, 
			bpp in ST_PS_Budget_Percentage_Parameters
			: 
			t==bpp.Time
			&& tr==bpp.Treatment_Id
		];
	 
		
	T_PS_Budget_Percentage_Parameters P_budgetPrcParameters[S_Planning_Horizon][S_Treatment_Id]
		= [	t : [tr: bpp] 
			| 
			t in S_Planning_Horizon, 
			tr in S_Treatment_Id, 
			bpp in  ST_PS_Budget_Percentage_Parameters
			: 
			bpp.Time==t 
			&& bpp.Treatment_Id==tr
		]; 	
	
	int P_Budget[S_Planning_Horizon] 									
		= [	t : bp.Budget
			| 
			t in S_Planning_Horizon, 
			bp in ST_PS_Budget_Parameters
			: 
		t==bp.Time
		];
	
	float P_AgePrc[S_Planning_Horizon]
		= [ t: bp.Age_Percentage
			|
			t in S_Planning_Horizon, 
			bp in ST_PS_Budget_Parameters
			: 
		t==bp.Time
		]; 
		
	// Customers would like to provide target age instead of the percentage	
	float P_AgeTarget[S_Planning_Horizon]
		= [ t: bp.Age_Percentage
			|
			t in S_Planning_Horizon, 
			bp in ST_PS_Budget_Parameters
			: 
		t==bp.Time
		];	
// ================================================================================================
// Model ==========================================================================================
// ================================================================================================
execute setOptimizationParameters{
  	// optimality tolerance
  	cplex.epopt = 0.02;
  	// absolute MIP gap tolerance
 	cplex.epagap = 0.02;
 	// relateive MIP gap tolerance
 	cplex.epgap = 0.02;
}

// VARIABLES ======================================================================================
	dvar boolean V_AssetPrescription[ST_PS_Asset_PrescriptionP];
	dvar float+ V_BudgetOverage[S_Planning_Horizon];
	dvar float+ V_MaxBudgetOverage; 
	dvar float+ V_AvgAssetAgeExcess[S_Planning_Horizon];
	
	dexpr int DE_AssetAge[a in S_Asset_Id][t in S_Planning_Horizon] 
		= maxl( 0, ( (P_assetAge[a] + t - P_fromYear) - sum(ap in ST_PS_Asset_PrescriptionP: ap.Asset_Id==a && t>ap.Time) ap.Service_Life_Extension*V_AssetPrescription[ap] ) );
	
	dexpr float DE_AvgAssetAge[t in S_Planning_Horizon] 
		= (sum(a in S_Asset_Id) P_assetLength[a]*DE_AssetAge[a][t])/(sum(a in S_Asset_Id) P_assetLength[a]);
	
	// Service Life extention at time t is achied by prescriptions starting at time (t-1)
	dexpr float DE_ServivceLifeExtension[t in S_Planning_Horizon]
		= sum(ap in ST_PS_Asset_PrescriptionP: ord(S_Planning_Horizon, ap.Time) == ord(S_Planning_Horizon,t)-1   ) 
			minl(ap.Service_Life_Extension, (P_assetAge[ap.Asset_Id] + ap.Time - P_fromYear))*V_AssetPrescription[ap];
		
	dexpr float obj1_ServiceLifeExtension 
		= sum(t  in S_Planning_Horizon) (card(S_Planning_Horizon)-ord(S_Planning_Horizon, t) + 1 )*DE_ServivceLifeExtension[t];
		// sum(ap in ST_PS_Asset_PrescriptionP) minl(ap.Service_Life_Extension, (P_assetAge[ap.Asset_Id] + ap.Time - P_fromYear))*V_AssetPrescription[ap]; 
		
	dexpr float obj2_BudgetSpending	
		= sum(ap in ST_PS_Asset_PrescriptionP) ap.Treatment_Cost*V_AssetPrescription[ap];
	
	dexpr float obj2_BudgetOverage 
		= sum(t in S_Planning_Horizon) V_BudgetOverage[t];
	
	dexpr float obj2_MaxBudgetOverage = V_MaxBudgetOverage; 	
	
	dexpr float obj2_AvgAssetAgeExcess 
		= sum(t in S_Planning_Horizon)V_AvgAssetAgeExcess[t];
// ================================================================================================

// OBJECTIVE ======================================================================================
	maximize 	  P_objON[1]*obj1_ServiceLifeExtension
				- P_objON[2]*(P_totalTreatmentCost*obj2_AvgAssetAgeExcess + obj2_MaxBudgetOverage + 00.1*obj2_BudgetOverage + 0.001*obj2_BudgetSpending)
				;
// ================================================================================================


// CONSTRAINTS ====================================================================================
subject to {
  	// Maximum one treatment during planning horizon
	//C_PrescriptionLimit:
	forall(a in S_Asset_Id)
	  	sum(ap in ST_PS_Asset_PrescriptionP: ap.Asset_Id==a) V_AssetPrescription[ap] <= 1;
  	
  	// Yearly budget constraint
	//C_Budget:
	forall(t in S_Planning_Horizon) 
		sum(ap in ST_PS_Asset_PrescriptionP: ap.Time==t) ap.Treatment_Cost*V_AssetPrescription[ap] <= P_Budget[t] + P_objON[2]*V_BudgetOverage[t];
		
  	// Budget by treatment type
  	//C_BudgetByTreatmentType:
	forall(t in S_Planning_Horizon, tr in S_Treatment_Id) {
	  	if (P_budgetPrcParameters[t][tr].Include_Exclude=="Y" && P_budgetPrcParameters[t][tr].Percentage > 0) 
			sum(ap in ST_PS_Asset_PrescriptionP: ap.Time==t && ap.Treatment_Id==tr) ap.Treatment_Cost*V_AssetPrescription[ap] 
				<= (P_Budget[t] + P_objON[2]*V_BudgetOverage[t])*P_BudgetPrcByTreatment[tr][t];	
			
		if (P_budgetPrcParameters[t][tr].Include_Exclude=="N")	
			sum(ap in ST_PS_Asset_PrescriptionP: ap.Time==t && ap.Treatment_Id==tr) V_AssetPrescription[ap] == 0;		
	}
	
  	if(P_objON[2]==1) {
  	  	// Budget Overage max deviation
  	  	//C_BudgetOverageMaxDeviation:
  	  	forall(t in S_Planning_Horizon)
  	  	  	V_MaxBudgetOverage >= V_BudgetOverage[t];
  	  	
  	  	// Average age sustainability constraint
  		// forall(t1, t2 in S_Planning_Horizon: ord(S_Planning_Horizon, t2)==ord(S_Planning_Horizon, t1)+1)
  		//C_AverageAgeSustainability:
  		forall(t in S_Planning_Horizon)
  		  	DE_AvgAssetAge[t] - V_AvgAssetAgeExcess[t] <= P_AgeTarget[t];  	
   	}  	   
  				
};
// ================================================================================================



// ================================================================================================
// Reports ========================================================================================
// ================================================================================================
int P_problemStatus = 0;
execute {
  if(cplex.getCplexStatus ()) P_problemStatus = 1; 
}

{T_PS_Execution_Objective} ST_PS_Execution_Status = { 
	<
	es.Scenario_Id,
	es.Objective_Id
	//P_problemStatus
	>|
	es in ST_PS_Execution_Objective
};	


// Asset Prescriptions Selected ===================================================================
	tuple T_Asset_Prescription_Results {
	  	T_PS_Asset_Prescription ap;
	  	int AssetAge;
	  	int LifeExtension;
	}; 
	
	{T_Asset_Prescription_Results} ST_Asset_Prescriptions_Selected = {
	  	<
	  	ap, 
	  	(P_assetAge[ap.Asset_Id] + ap.Time - P_fromYear),
	  	minl(ap.Service_Life_Extension, (P_assetAge[ap.Asset_Id] + ap.Time - P_fromYear))
	  	> | 
	  	ap in ST_PS_Asset_PrescriptionP 
	  	: 
	  	V_AssetPrescription[ap]==1
	}; 


// Asset Prescriptions Remained ===================================================================
	tuple T_Asset_Year { 
		string Asset_Id;
		int Time;
	};

	// if an asset is prescribed at time t, then it should be removed from the list at time >= t 
	{T_Asset_Year} S_Prescribed_AssetsYear = {
	  	<
	  	apr.ap.Asset_Id, 
	  	t
	  	> | 
	  	apr in ST_Asset_Prescriptions_Selected, 
	  	t in S_Planning_Horizon
	  	: 
	  	t>=apr.ap.Time
	}; 

	{T_Asset_Year} S_All_AssetsYear = {
	  	<
	  	ap.Asset_Id, 
	  	ap.Time
	  	> | 
	  	ap in ST_PS_Asset_Prescription
	};
	
	{T_Asset_Year} S_Unprescribed_AssetsYear = S_All_AssetsYear diff S_Prescribed_AssetsYear;

	{T_PS_Asset_Prescription} ST_Asset_Prescriptions_Remained = {
	  	ap 
	  	| 
	  	ay in S_Unprescribed_AssetsYear, 
	  	ap in ST_PS_Asset_Prescription
		: 
		ay.Asset_Id==ap.Asset_Id 
		&& ay.Time==ap.Time
	};



// Money Spent by Treatment Type by Year : show pie chart =========================================
	float P_moneySpentByYear[t in S_Planning_Horizon] = sum(aps in ST_Asset_Prescriptions_Selected: aps.ap.Time==t) aps.ap.Treatment_Cost;
	float TotalMoneySpent = sum(aps in ST_Asset_Prescriptions_Selected) aps.ap.Treatment_Cost;	
	
	tuple T_PS_Budget_Treatment_Allocation {
	  	int Scenario_Id;
	  	int Time;
	  	int Treatment_Id;
	  	float Budget_Allocation;
	}; 
	
	{T_PS_Budget_Treatment_Allocation} ST_PS_Budget_Treatment_Allocation = {
	  	<
		P_scenarioId,
		t, 
		tr, 
		sum(aps in ST_Asset_Prescriptions_Selected: aps.ap.Time==t && aps.ap.Treatment_Id==tr) aps.ap.Treatment_Cost
		>| 
		t in S_Planning_Horizon, 
		tr in S_Treatment_Id
	};	


// Sustainability Analysis showing Remaining Service Life by Year =================================
// (show both  before and after optimization)

		

/*
int P_cumLifeExtensionByAsset[S_Asset_Id][S_Planning_Horizon] 
	= [aps.ap.Asset_Id: [t : aps.LifeExtension]
		|
		t in S_Planning_Horizon,
		aps in ST_Asset_Prescriptions_Selected
		:
		t >= aps.ap.Time
	];
	
float P_assetAgeLengthByYearAfter[a in S_Asset_Id][t in S_Planning_Horizon]
	= P_assetLength[a]* ( (P_assetAge[a] + t - P_fromYear) - P_cumLifeExtensionByAsset[a][t]);

float P_avgAgeByYearAfter[S_Planning_Horizon] 
	= [	t : (sum(a in S_Asset_Id) P_assetAgeLengthByYearAfter[a][t]) / (sum(a in S_Asset_Id) P_assetLength[a])
		| t in S_Planning_Horizon
	];
*/

tuple T_PS_Sustainability {
  	int Scenario_Id;
  	int Time; 
  	float Money_Spent;
  	float Average_Age_Before;
  	float Average_Age_After;
  	float Budget;
}; 


{T_PS_Sustainability} ST_PS_Sustainability = {
  	<
	P_scenarioId, 
	t,
	P_moneySpentByYear[t],
	round(100*P_avgAgeByYear[t])/100,
	// round(100*P_avgAgeByYearAfter[t])/100
	round(100*DE_AvgAssetAge[t])/100,
	P_Budget[t]
	>|
	t in S_Planning_Horizon
};

execute { 
 	//ST_PS_Execution_Status;
	ST_PS_Sustainability;
	ST_PS_Budget_Treatment_Allocation;
	ST_Asset_Prescriptions_Remained;
	S_Unprescribed_AssetsYear;
}	


