/*********************************************
 * 
 * Copyright (C) 1990-2014 by IBM.
 *  All Rights Reserved.
 *
 *  N O T I C E
 *
 *  THIS MATERIAL IS CONSIDERED A TRADE SECRET BY IBM.
 *  UNAUTHORIZED ACCESS, USE, REPRODUCTION OR DISTRIBUTION IS PROHIBITED.
 * *********************************************
 * 
 * 
 * IMPORTANT:
 * =========
 * This code is part of ARMOR3 Research Asset. It cannot be copied for any other use
 * except ARMOR3 project
 * Please contact ARMOR3 Team for any questions
 *
 *
 *
 * OPL 12.6 Model
 * Author: Abhishek Raman
 *********************************************/

// INPUT DATA =====================================================================================
	tuple T_PS_Execution_Scenario {
	  	string Asset_Class_Id;
 	};
 	{T_PS_Execution_Scenario} ST_PS_Execution_Scenario = ...;	  
	
	tuple T_PS_Error_Info {
	  	int Error_Code;
	  	string Error_Description;
	  	string Error_Impact;
	  	string Criticality;
	  	string Source_Table;
	};
	{T_PS_Error_Info} ST_PS_Error_Info = ...;	
	
	tuple T_PS_Driver { 
		int Driver_Id; 
		string Driver_Name;
		string Driver_Description;
	};	
	{T_PS_Driver} ST_PS_Driver = ...;
	
	tuple T_PS_Factor { 
		int Factor_Id;
		string Factor_Name;
		string Factor_Description;
	};	
	{T_PS_Factor} ST_PS_Factor = ...; 
	
	tuple T_PS_Treatment {
 		int Treatment_Id;
 		string Treatment_Name;
 		string Treatment_Description;
 		string Replace_VS_Rehab;
 	};	  
	{T_PS_Treatment} ST_PS_Treatment = ...; 
	
	tuple T_PS_Asset_X_Driver {
	  	string Asset_Class_Id;
	  	int Driver_Id;
	  	int Driver_Index;
	}; 
	{T_PS_Asset_X_Driver} ST_PS_Asset_X_Driver = ...; 
 
	tuple T_PS_Driver_X_Factor {
	  	string Asset_Class_Id;
	  	int Driver_Id;
	  	int Factor_Id;
	  	int Factor_Index;
	  	string Default_Value;
	}; 
	{T_PS_Driver_X_Factor} ST_PS_Driver_X_Factor = ...; 
	
	tuple T_PS_Factor_Index {
	  	string Asset_Class_Id;
	  	int Driver_Id;
	  	int Factor_Id;
	  	int Index_Sequence_Id;
	  	string Index_Type;
	  	int From_Range;
	  	int To_Range;
	  	string String_Value;
	  	int Int_Value;
	  	int Index_Value; 
	};
	{T_PS_Factor_Index} ST_PS_Factor_Index = ...;
	
	tuple T_PS_Asset_Performance_X_Treatment {
	  	string Asset_Class_Id;
	  	int Treatment_Id;
	  	int Driver_Id;
	  	int From_Range;
	  	int To_Range;
	};		
	{T_PS_Asset_Performance_X_Treatment} ST_PS_Asset_Performance_X_Treatment = ...;
	
	tuple T_PS_Degradation {
	  	string Asset_Class_Id;
	  	int Factor_Id;
	  	int Age;
	  	string Description;
	  	float Cumulative_Degradation;
  	};
  	{T_PS_Degradation} ST_PS_Degradation = ...;
  	
  	// New Data ---
  	tuple T_PS_Scenario { 
		string Asset_Class_Id;
	};
	{T_PS_Scenario} ST_PS_Scenario = ...;
	
  	tuple T_Asset_Id {
	  	string Asset_Id;
	  	string Asset_Class_Id;
	}; 
	{T_Asset_Id} ST_Asset_Id = ...;
	
	tuple T_PS_Asset_Factor {
	  	string Asset_Id;
	  	int Factor_Id;
	  	string Factor_Value;
	  	int Time;
	};
	{T_PS_Asset_Factor} ST_PS_Asset_Factor = ...;
	
	tuple T_PS_Factor_Id_Age { 
		int Factor_Id;
	};
	{T_PS_Factor_Id_Age} ST_PS_Factor_Id_Age = ...;
  	
  	tuple T_PS_Factor_Id_Length { 
		int Factor_Id;
	};
	{T_PS_Factor_Id_Length} ST_PS_Factor_Id_Length = ...;		  	
// INTERNAL DATA ==================================================================================

	string P_assetClassId;
	execute{
		for (var ep in ST_PS_Scenario){
			P_assetClassId = ep.Asset_Class_Id;
		}
	}
	int P_assetAgeFactorIndex = min(fi in ST_PS_Factor_Id_Age) fi.Factor_Id; //2;
	int P_assetLengthFactorIndex = min(fi in ST_PS_Factor_Id_Length) fi.Factor_Id;
	
	{int} S_errorCode = {ei.Error_Code | ei in ST_PS_Error_Info};

	T_PS_Error_Info P_errorInfo[S_errorCode] = [
		ec
		: 
		ei 
		| 
		ec in S_errorCode, 
		ei in ST_PS_Error_Info
		: 
		ec==ei.Error_Code
	];
	
	{int} S_driverId = {d.Driver_Id | d in ST_PS_Driver};
	T_PS_Driver P_driverName[S_driverId] = [
		di
		: 
		d
		|
		di in S_driverId,
		d in ST_PS_Driver
		:
		d.Driver_Id==di
	];
	
	{int} S_factorId = {d.Factor_Id | d in ST_PS_Factor};
	T_PS_Factor P_factorName[S_factorId] = [
		fi
		: 
		f
		|
		fi in S_factorId,
		f in ST_PS_Factor
		:
		f.Factor_Id==fi
	];
	
	{int} S_treatmentId = {d.Treatment_Id | d in ST_PS_Treatment};
	T_PS_Treatment P_treatmentName[S_treatmentId] = [
		ti
		: 
		t
		|
		ti in S_treatmentId,
		t in ST_PS_Treatment
		:
		t.Treatment_Id==ti
	];
	
	tuple T_Factor_Range {
	  	int Driver_Id;
	  	int Factor_Id;
	  	int From_Range;
	  	int To_Range;
	};
	sorted {T_Factor_Range} ST_Factor_Range = {
	  	<
	  	fi.Driver_Id,
	  	fi.Factor_Id,
	  	fi.From_Range,
	  	fi.To_Range
	  	>| 
	  	fi in ST_PS_Factor_Index
	  	: 
	  	fi.Index_Type=="Range"
	};	
	
	tuple T_Factor_Int {
	  	int Driver_Id;
	  	int Factor_Id;
	  	int Int_Value;
	};
	sorted {T_Factor_Int} ST_Factor_Int = {
	  	<
	  	fi.Driver_Id,
	  	fi.Factor_Id,
	  	fi.Int_Value
	  	>| 
	  	fi in ST_PS_Factor_Index
	  	: 
	  	fi.Index_Type=="Int"
	};
	
	tuple T_Factor_String {
	  	int Driver_Id;
	  	int Factor_Id;
	  	string String_Value;
	};
	sorted {T_Factor_String} ST_Factor_String = {
	  	<
	  	fi.Driver_Id,
	  	fi.Factor_Id,
	  	fi.String_Value
	  	>| 
	  	fi in ST_PS_Factor_Index
	  	: 
	  	fi.Index_Type=="String"
	};	
			
// OUTPUT TABLE ===================================================================================
	tuple T_PS_Validation {
	  	string Asset_Class_Id;
	  	string Source_Table;
	  	int Error_Code;
	  	string Error_Description;
	  	string Error_Impact;
	  	string Criticality;
	  	string Details;
	};
	{T_PS_Validation} ST_PS_Validation; 	
	 
	 
// REPORTS ========================================================================================
	// Driver index values are not summing up to 100 ----------------------------------------------
	int P_sumDriverIndex = sum(ad in ST_PS_Asset_X_Driver) ad.Driver_Index;
	
	execute { 
		if(P_sumDriverIndex != 100) {
			ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[1].Source_Table, 
				1, 
				P_errorInfo[1].Error_Description, 
				P_errorInfo[1].Error_Impact, 
				P_errorInfo[1].Criticality,
				""); 
			// writeln(ST_PS_Validation);
		}			
	};	
	
	
	// Factor index values are not summing up to 100 (for all drivers having index > 0) -----------
	tuple T_Active_Drivers { 
		int Driver_Id;
		string Driver_Name;
	};
	
	{T_Active_Drivers} ST_Active_Drivers = {
	  	<
	  	ad.Driver_Id,
	  	d.Driver_Name 
	  	>| 
	  	ad in ST_PS_Asset_X_Driver, 
	  	d in ST_PS_Driver
	  	: 
	  	ad.Driver_Id==d.Driver_Id 
	  	&& ad.Driver_Index > 0};
	
	int P_sumDriversFactorIndex[ST_Active_Drivers] = [
		ad
		: 
		sum(df in ST_PS_Driver_X_Factor: df.Driver_Id==ad.Driver_Id) df.Factor_Index
		|
		ad in ST_Active_Drivers
	];		
	
	execute { 
		for(var ad in ST_Active_Drivers) {
  			if(P_sumDriversFactorIndex[ad] != 100) {
     			ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[2].Source_Table, 
				2, 
				P_errorInfo[2].Error_Description, 
				P_errorInfo[2].Error_Impact, 
				P_errorInfo[2].Criticality,
				ad.Driver_Name);
     		}  			  
  		}		  
	}	
	
	// Driver-Factor default value is missing -----------------------------------------------------
	execute {
		for(var df in ST_PS_Driver_X_Factor) {
			if(df.Default_Value=="") {
				ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[3].Source_Table, 
				3, 
				P_errorInfo[3].Error_Description, 
				P_errorInfo[3].Error_Impact, 
				P_errorInfo[3].Criticality,
				P_driverName[df.Driver_Id].Driver_Name + "/" + P_factorName[df.Factor_Id].Factor_Name);
 			}			
		}		
	}		
	
	
	// Factor-Index range has overlap -------------------------------------------------------------
	
	tuple T_Factor_Range_Overlap { 
		int Driver_Id;
		int Factor_Id;
		int From_Range;
	};
	
	{T_Factor_Range_Overlap} ST_Factor_Range_Overlap = 
		// range to range overlap
		{
		<
		fr1.Driver_Id,
		fr1.Factor_Id,
		fr2.From_Range
		>|
		fr1 in ST_Factor_Range, 
		fr2 in ST_Factor_Range  	
	  	:
	  	fr1.Driver_Id==fr2.Driver_Id 
	  	&& fr1.Factor_Id==fr2.Factor_Id
	  	&& ord(ST_Factor_Range,fr2)== ord(ST_Factor_Range,fr1)+1
	  	&& fr2.From_Range < fr1.To_Range
		}			
		union 
		// integer to integer overlap
		{ 
		<
		fi1.Driver_Id,
		fi1.Factor_Id,
		fi1.Int_Value
		>|
		fi1 in ST_Factor_Int,
		fi2 in ST_Factor_Int
		:
		fi1.Driver_Id==fi2.Driver_Id 
	  	&& fi1.Factor_Id==fi2.Factor_Id 
	  	&& ord(ST_Factor_Int,fi2)==ord(ST_Factor_Int,fi1)+1 
		&& fi1.Int_Value==fi2.Int_Value  
		} 	
		union 
		// integer to range overlap
		{
		<
		fi1.Driver_Id,
		fi1.Factor_Id,
		fi1.Int_Value
		>|
		fi1 in ST_Factor_Int,
		fr2 in ST_Factor_Range 
		:
		fi1.Driver_Id==fr2.Driver_Id 
	  	&& fi1.Factor_Id==fr2.Factor_Id  
		&& fi1.Int_Value>=fr2.From_Range   
		&& fi1.Int_Value<fr2.To_Range  
  		};		  
	
	
	execute {
	  	for(var fro in ST_Factor_Range_Overlap) {
			ST_PS_Validation.add(
			P_assetClassId, 
			P_errorInfo[4].Source_Table, 
			4, 
			P_errorInfo[4].Error_Description, 
			P_errorInfo[4].Error_Impact, 
			P_errorInfo[4].Criticality,
			P_driverName[fro.Driver_Id].Driver_Name + "/" + P_factorName[fro.Factor_Id].Factor_Name + " - around value: " + fro.From_Range);			
		}	  	  
	};	
	
	// Factor-Index is not defined for all factor values ------------------------------------------ 
	tuple T_Driver_Factor { 
		int Driver_Id;
		int Factor_Id;
	};	
	// String factor values not defined
		{T_Driver_Factor} ST_Driver_Factor_String = { 
			<
			fs.Driver_Id,
			fs.Factor_Id
			>|
			fs in ST_Factor_String
		};
		{int} S_FactorId_String = {df.Factor_Id | df in ST_Driver_Factor_String}; 
		
		// get all factor values defined in factor index table 	
		{string} S_Factor_Values_inIndex_String[df in ST_Driver_Factor_String] = {fs.String_Value | fs in ST_Factor_String : fs.Driver_Id==df.Driver_Id && fs.Factor_Id==df.Factor_Id};	  
		
		// get all factor values defined in asset_factor table 
		sorted {string} S_Factor_Values_inAssetFactor_String[fi in S_FactorId_String] = {af.Factor_Value | af in ST_PS_Asset_Factor : af.Factor_Id==fi}; 
		
		
		sorted {string} S_Factor_Values_inAssetFactor_String_UnDefined[df in ST_Driver_Factor_String] = 
					S_Factor_Values_inAssetFactor_String[df.Factor_Id] diff S_Factor_Values_inIndex_String[df];


	// Numeric (Int + Range) factor values not defined
		{T_Driver_Factor} ST_Driver_Factor_Numeric = { 
			<
			fs.Driver_Id,
			fs.Factor_Id
			>|
			fs in ST_Factor_Int
			}
			union 
			{ 
			<
			fs.Driver_Id,
			fs.Factor_Id
			>|
			fs in ST_Factor_Range
			};
			
		{int} S_FactorId_Numeric = {df.Factor_Id | df in ST_Driver_Factor_Numeric}; 
		
		// get all factor values defined in asset_factor table , include degradation cumulative values
		{float} S_Factor_Values_inAssetFactor_Numeric[df in ST_Driver_Factor_Numeric] = {floatValue(af.Factor_Value) | af in ST_PS_Asset_Factor : af.Factor_Id==df.Factor_Id}
		union
		{floatValue(af.Factor_Value)+ deg.Cumulative_Degradation | af in ST_PS_Asset_Factor, deg in ST_PS_Degradation : af.Factor_Id==df.Factor_Id && af.Factor_Id==deg.Factor_Id};
		
		{float} S_Factor_Values_inAssetFactor_Numeric_Defined[ST_Driver_Factor_Numeric];
	
		
		{T_Factor_Range} ST_Factor_Range_Indexed[df in ST_Driver_Factor_Numeric] = { 
			fr	  
			|
			fr in ST_Factor_Range
			:
			fr.Driver_Id==df.Driver_Id 
			&& fr.Factor_Id==df.Factor_Id
  		};
  		{T_Factor_Int} ST_Factor_Int_Indexed[df in ST_Driver_Factor_Numeric] = { 
			fr	  
			|
			fr in ST_Factor_Int
			:
			fr.Driver_Id==df.Driver_Id 
			&& fr.Factor_Id==df.Factor_Id
  		};		  
		
		execute Calc_UndefinedFactorValues { 
			for(var df in ST_Driver_Factor_Numeric) { 
				for(var fn in S_Factor_Values_inAssetFactor_Numeric[df]) { 
					//range 
					for(var fr in ST_Factor_Range_Indexed[df]) {
						if(fn >= fr.From_Range && fn < fr.To_Range) 
							S_Factor_Values_inAssetFactor_Numeric_Defined[df].add(fn);
   					}
   					//int
   					for(var fi in ST_Factor_Int_Indexed[df]) {
						if(fn == fi.Int_Value) 
							S_Factor_Values_inAssetFactor_Numeric_Defined[df].add(fn);
   					}
  				}
			}  				
		}			
		
		sorted {float} S_Factor_Values_inAssetFactor_Numeric_UnDefined[df in ST_Driver_Factor_Numeric] = 
				S_Factor_Values_inAssetFactor_Numeric[df] diff S_Factor_Values_inAssetFactor_Numeric_Defined[df];
		
		execute {
		  	S_Factor_Values_inAssetFactor_Numeric;
		  	S_Factor_Values_inAssetFactor_Numeric_UnDefined;
	 	};
	
	execute Add_S_Factor_Values_inAssetFactor_String_UnDefined{ 
		for(var df in ST_Driver_Factor_String) {
			for(var fs in S_Factor_Values_inAssetFactor_String_UnDefined[df]) {
				if( Opl.first(S_Factor_Values_inAssetFactor_String_UnDefined[df]) == "" || Opl.first(S_Factor_Values_inAssetFactor_String_UnDefined[df]) == null)
					if( Opl.last(S_Factor_Values_inAssetFactor_String_UnDefined[df]) == "" || Opl.last(S_Factor_Values_inAssetFactor_String_UnDefined[df]) == null)
					{
						continue;
					}
				ST_PS_Validation.add(
					P_assetClassId, 
					P_errorInfo[5].Source_Table, 
					5, 
					P_errorInfo[5].Error_Description, 
					P_errorInfo[5].Error_Impact, 
					P_errorInfo[5].Criticality,
					P_driverName[df.Driver_Id].Driver_Name + "/" + P_factorName[df.Factor_Id].Factor_Name + " for values: (" + 
						Opl.first(S_Factor_Values_inAssetFactor_String_UnDefined[df])+", ..., "+ Opl.last(S_Factor_Values_inAssetFactor_String_UnDefined[df])+")" 
				 	);
			}
 		}
	};
	execute Add_S_Factor_Values_inAssetFactor_Numeric_UnDefined{ 
		for(var df in ST_Driver_Factor_Numeric) {
			for(var fs in S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) {
				if(Opl.first(S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) == "" || Opl.first(S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) == null)
					if(Opl.last(S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) == "" || Opl.last(S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) == null)
					{
						continue;
					}
				ST_PS_Validation.add(
					P_assetClassId, 
					P_errorInfo[5].Source_Table, 
					5, 
					P_errorInfo[5].Error_Description, 
					P_errorInfo[5].Error_Impact, 
					P_errorInfo[5].Criticality,
					P_driverName[df.Driver_Id].Driver_Name + "/" + P_factorName[df.Factor_Id].Factor_Name + " for values: (" + 
						Opl.first(S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) + ", ..., " + Opl.last(S_Factor_Values_inAssetFactor_Numeric_UnDefined[df]) +")" 
				 	);
			}
 		}
	};
	
	
	
	// Factor-Index range has missing interval ----------------------------------------------------
	tuple T_Factor_Range_Missing_Interval { 
		int Driver_Id;
		int Factor_Id;
		int To_Range;
		int From_Range;
	};
	
	{T_Factor_Range_Missing_Interval} ST_Factor_Range_Missing_Interval = {
		<
		fr1.Driver_Id,
		fr1.Factor_Id,
		fr1.To_Range,
		fr2.From_Range
		>|
		fr1 in ST_Factor_Range, 
		fr2 in ST_Factor_Range  	
	  	:
	  	fr1.Driver_Id==fr2.Driver_Id 
	  	&& fr1.Factor_Id==fr2.Factor_Id
	  	&& ord(ST_Factor_Range,fr2)== ord(ST_Factor_Range,fr1)+1
	  	&& fr2.From_Range > fr1.To_Range
	};			
	
	execute {
	  	for(var frm in ST_Factor_Range_Missing_Interval) {
			ST_PS_Validation.add(
			P_assetClassId, 
			P_errorInfo[5].Source_Table, 
			5, 
			P_errorInfo[5].Error_Description, 
			P_errorInfo[5].Error_Impact, 
			P_errorInfo[5].Criticality,
			P_driverName[frm.Driver_Id].Driver_Name + "/" + P_factorName[frm.Factor_Id].Factor_Name + " - at interval: (" + frm.To_Range + " - " + frm.From_Range +")");			
		}	  	  
	};	
	
	
	// Driver-Factor range has from-range less then to-range
	tuple T_Factor_Range_Misdefinition { 
		int Driver_Id;
		int Factor_Id;
		int From_Range;
		int To_Range;
	};
	
	{T_Factor_Range_Misdefinition} ST_Factor_Range_Misdefinition = {
		<
		fr1.Driver_Id,
		fr1.Factor_Id,
		fr1.From_Range,
		fr1.To_Range
		>|
		fr1 in ST_Factor_Range 	
	  	:
	  	fr1.From_Range >= fr1.To_Range
	};			

	execute {
	  	for(var frm in ST_Factor_Range_Misdefinition) {
			ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[6].Source_Table, 
				6, 
				P_errorInfo[6].Error_Description, 
				P_errorInfo[6].Error_Impact, 
				P_errorInfo[6].Criticality,
				P_driverName[frm.Driver_Id].Driver_Name + "/" + P_factorName[frm.Factor_Id].Factor_Name + " - at range: (" + frm.From_Range + " - " + frm.To_Range +")");			
		}	  	  
	};	
	
	// Treatment Applicability has range-higher-limit less than range-lower-limit
	
	execute {
	  	for(var apt in ST_PS_Asset_Performance_X_Treatment) {
	  	  	if(apt.To_Range <= apt.From_Range) {
				ST_PS_Validation.add(
					P_assetClassId, 
					P_errorInfo[7].Source_Table, 
					7, 
					P_errorInfo[7].Error_Description, 
					P_errorInfo[7].Error_Impact, 
					P_errorInfo[7].Criticality,
					P_treatmentName[apt.Treatment_Id].Treatment_Name + "/" + P_driverName[apt.Driver_Id].Driver_Name + " - at range: (" + apt.From_Range + " - " + apt.To_Range +")");			
 			}			
		}	  	  
	};	
	
	// Degradation for asset factor is not defined for full life span
	{int} S_degradatoinFactors = {d.Factor_Id | d in ST_PS_Degradation};
	/*
	int P_maxDegradationAge[S_degradatoinFactors] = [
		df
		:
		maxl(d.Age)
		|
		d in ST_PS_Degradation,
		df in S_degradatoinFactors
		:
		d.Factor_Id==df
	]; 
	*/
	int P_maxDegradationAge[S_degradatoinFactors];
	execute {
	  	for(var df0 in S_degradatoinFactors) { 
	  		P_maxDegradationAge[df0]=0;
	  		for(var d0 in ST_PS_Degradation) {
	  			if(df0==d0.Factor_Id && d0.Age > P_maxDegradationAge[df0]) {
     				P_maxDegradationAge[df0] = d0.Age;
     			}             				  			    
     		}	  		  
  		}	  	
	  
	  	var P_maxAge = 0;
	  	for(var fr in ST_Factor_Range) {
	  	  	if(fr.Factor_Id == P_assetAgeFactorIndex && fr.To_Range > P_maxAge) {
	  	  	  	P_maxAge = fr.To_Range;
     		}
    	}

	  	for(var df in S_degradatoinFactors) {
	  	  	if(P_maxDegradationAge[df] < P_maxAge) {
				ST_PS_Validation.add(
					P_assetClassId, 
					P_errorInfo[8].Source_Table, 
					8, 
					P_errorInfo[8].Error_Description, 
					P_errorInfo[8].Error_Impact, 
					P_errorInfo[8].Criticality,
					"Degradation is not defined for " + P_factorName[df].Factor_Name + " - older than " + P_maxDegradationAge[df] + " years old");			
 			}			
		}	  	  
	};	
	
	// Driver weight is set to zero ---------------------------------------------------------------
		int P_AssetDriverWeigth[ST_PS_Asset_X_Driver] = [
			ad
			: 
			ad.Driver_Index
			|
			ad in ST_PS_Asset_X_Driver
		];		
		
		execute { 
			for(var ad in ST_PS_Asset_X_Driver) {
	  			if(P_AssetDriverWeigth[ad] == 0) {
	     			ST_PS_Validation.add(
					P_assetClassId, 
					P_errorInfo[10].Source_Table, 
					10, 
					P_errorInfo[10].Error_Description, 
					P_errorInfo[10].Error_Impact, 
					P_errorInfo[10].Criticality,
					"Driver weigth is zero for: " + P_driverName[ad.Driver_Id].Driver_Name);
	     		}  			  
	  		}		  
		}	
	
	// Factor range is not defined ----------------------------------------------------------------
		tuple T_DriverFactor_Pairs { 
			int Driver_Id;
			int Factor_Id;
		};
		{T_DriverFactor_Pairs} ST_DriverFactor_Pairs = { 
			<
			df.Driver_Id,
			df.Factor_Id
			>|
			df in ST_PS_Driver_X_Factor
		};		
		
		{T_DriverFactor_Pairs} ST_DriverFactor_Pairs_hasIndex = { 
			<
			df.Driver_Id,
			df.Factor_Id
			>|
			df in ST_PS_Factor_Index
		};		
		
		{T_DriverFactor_Pairs} ST_DriverFactor_Pairs_noIndex = ST_DriverFactor_Pairs diff ST_DriverFactor_Pairs_hasIndex;
				
		execute { 
			for(var df in ST_DriverFactor_Pairs_noIndex) {
     			ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[9].Source_Table, 
				9, 
				P_errorInfo[9].Error_Description, 
				P_errorInfo[9].Error_Impact, 
				P_errorInfo[9].Criticality,
				"Driver-Factor indexes are undefined for: " + P_driverName[df.Driver_Id].Driver_Name + "-" + P_factorName[df.Factor_Id].Factor_Name);
	  		}		  
		}
		
	
	// Assets missing the Age information ---------------------------------------------------------
		{string} S_Asset_Id_All = {a.Asset_Id | a in ST_Asset_Id, s in ST_PS_Scenario : a.Asset_Class_Id==s.Asset_Class_Id};
		{string} S_Asset_Id_WithAge = {af.Asset_Id | af in ST_PS_Asset_Factor: af.Factor_Id==P_assetAgeFactorIndex}; 
		{string} S_Asset_Id_WithoutAge = S_Asset_Id_All diff S_Asset_Id_WithAge; 
	
		execute { 
			if(Opl.card(S_Asset_Id_WithoutAge)>0) {
     			ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[11].Source_Table, 
				11, 
				P_errorInfo[11].Error_Description, 
				P_errorInfo[11].Error_Impact, 
				P_errorInfo[11].Criticality,
				"Number of assets without age information: " + Opl.card(S_Asset_Id_WithoutAge));
	  		}		  
		}
	  
 	
 	// Assets missing or having zero Length information -------------------------------------------
		{string} S_Asset_Id_WithLength = {af.Asset_Id | af in ST_PS_Asset_Factor: af.Factor_Id==P_assetLengthFactorIndex && floatValue(af.Factor_Value) > 0}; 
		{string} S_Asset_Id_WithoutLength = S_Asset_Id_All diff S_Asset_Id_WithLength; 
	
		
		/*
		 * comment off this validation check as some non-cable assets could not have length, 
		 * their length will be assigned to'1' at run time
		execute { 
			if(Opl.card(S_Asset_Id_WithoutLength)>0) {
     			ST_PS_Validation.add(
				P_assetClassId, 
				P_errorInfo[12].Source_Table, 
				12, 
				P_errorInfo[12].Error_Description, 
				P_errorInfo[12].Error_Impact, 
				P_errorInfo[12].Criticality,
				"Number of assets with zero length (quantity): " + Opl.card(S_Asset_Id_WithoutLength));
	  		}		  
		}
		*/
	
	
	execute {
	  	S_Asset_Id_WithoutAge;
	  	S_Asset_Id_WithoutLength;
 		writeln(ST_PS_Validation);
 	};	  
		 