/*
* Licensed Materials - Property of IBM
*
* IBM Insights Foundation for Energy  5725-W39
*
* (C) Copyright IBM Corp.  2015, 2016   All rights reserved.
*
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with
* IBM Corp.
 */ 

/*********************************************
 * OPL 6.1.1 Model
 * Author: ktarun
 * Creation Date: Oct 3, 2010 at 6:16:48 AM
 *********************************************/

using CP;

 tuple WorkOrderType {
 key int woId;
 string woName;
 int woPriority;
 int woDuration;
 int woLocations;
 };
 
 tuple CrewType {
 key int crewId;
 string crewName;
 int shiftPeriod;
 };
 
 tuple WorkOrderTravelTimeType {
 key int fromWo;
 key int toWo;
 int time;
 };
 
 tuple ParameterType {
 int deadline;
 int cp_timelimit;
 };
 
 tuple RoutScheduleType {
 key int woId;
 key int crewId;
 int seq;
 int start;
 int end;
 };
 
 
 {WorkOrderType} workOrder = ...;
 
 {CrewType} crew = ...;
 
 {WorkOrderTravelTimeType} workOrderTime = ...;
 
 {ParameterType} Parameters = {<40,5>};
 
 
 int taskLocations[wo in workOrder] = wo.woLocations;
 
 int cp_timelimit = first(Parameters).cp_timelimit;
 dvar interval task[wo in workOrder] optional in 0..first(Parameters).deadline size wo.woDuration;
 dvar interval alttasks[wo in workOrder][cr in crew] optional in 0..first(Parameters).deadline size wo.woDuration;
 dvar sequence seq[cr in crew] in all (wo in workOrder)alttasks[wo][cr] types taskLocations;
 
 
 execute {
	cp.param.TimeLimit=cp_timelimit;
}
 
 dexpr float obj = sum(cr in crew) max(wo in workOrder) (endOf(alttasks[wo][cr]));
 
 
 maximize -1 * obj;
 
 subject to {
 
 	forall (wo in workOrder)
		alternative(task[wo],all(cr in crew) alttasks[wo][cr]);
		
	forall(cr in crew)
		noOverlap(seq[cr],workOrderTime);
		
		forall(wo in workOrder) {
				presenceOf(task[wo]);
		}
 
 }
 
 {RoutScheduleType} RoutSchedules = {<wo.woId,crew.crewId,1,1,1> | wo in workOrder, crew in crew};
 

 execute {
  writeln(RoutSchedules);
  for(var t in task) {
    writeln(t + " on [" + task[t].start + "," + task[t].end + ")");
  }
  for(var c in crew) {
  	for(var w in workOrder) {
  		if(alttasks[w][c].present > 0) {
  			writeln("Crew " + c.crewId + " working on " + w.woId +"  starts at " + alttasks[w][c].start + " ends at " + alttasks[w][c].end);
  		}
  	}
  }
}
 