#!/bin/bash

SOURCE="${BASH_SOURCE[0]}"
DIR="$( dirname "$SOURCE" )"
cd $DIR
ENV_ROOT=$PWD

if [ $# -ne 3 ]; then
        echo "Usage: $0 <modeler server config> <stream parameter config> <stream execution order config>"
        exit 1
fi

modelerServerCfg=$1

# all streams' params definition
streamParamsCfg=$2

# stream execution order definition
streamOrderCfg=$3

# params of each streams
strParams=""

# comman params
comParams=""

source $modelerServerCfg
password=`$ENV_ROOT/../lib/encrypt.sh $password`

function getCommonParams(){
    comParams=""
    while IFS='' read -r line || [[ -n "$line" ]]; do
        size=${#line}
        if [ $size -ne 0 ]; then

            if [ "${line:0:1}" = "#" ] ; then
                # ignore comments
                continue
            elif [ "${line:0:1}" = "["  ] ; then
                break
            else

               #echo "common param: $line"
               if [ "${line:0:1}" = "-"  ] ; then
                   # options for modeler batch are start with "-"
                   comParams=${comParams}" "${line}
               else
                   # other options belong to stream
                   if [ "${line:0:6}" = "dspwd="  ] ; then
                       dspwd=`$ENV_ROOT/../lib/encrypt.sh ${line:6}`
                       line="dspwd=$dspwd"
                   fi
                   comParams=${comParams}" "-P${line}
               fi

            fi

        fi
    done < "$streamParamsCfg"
}

function getParams(){
streamName=$1

# flag to check if this line is the parameter of current stream
isCurrentStrParam=0

strParams=""
while IFS='' read -r line || [[ -n "$line" ]]; do
        size=${#line}
        if [ $size -ne 0 ]; then

            if [ "${line:0:1}" = "[" ] ; then
              if [ "$line" = "[${streamName}]" ] ; then
                #echo "----get params for stream: $line"
                isCurrentStrParam=1
                continue
              else
                isCurrentStrParam=0
              fi
            fi

            if [ ${isCurrentStrParam} -eq 1 ] ; then
               if [ "${line:0:1}" = "#"  ] ; then
                   # ignore comments
                   continue
               elif [ "${line:0:1}" = "-"  ] ; then
                   # options for modeler batch are start with "-"
                   #echo "stream param: $line"
                   strParams=${strParams}" "${line}
               else
                   # other options belong to stream
                   #echo "stream param: $line"
                   if [ "${line:0:6}" = "dspwd="  ] ; then
                       dspwd=`$ENV_ROOT/../lib/encrypt.sh ${line:6}`
                       line="dspwd=$dspwd"
                   fi
                   strParams=${strParams}" "-P${line}
               fi
            fi
        fi
done < "$streamParamsCfg"
}

function executeStream(){
    stream=$1
    getCommonParams
    getParams $stream
    TIMESTMAP=`date +%Y-%m-%d,%H:%M:%S`
    echo "$TIMESTMAP start executing stream: $stream"
    $modelerBatch/clemb -stream $stream -server -hostname $hostname -username $user -password $password ${comParams} -PisEncrypted=false ${strParams} -execute
    exitCode=$?
    TIMESTMAP=`date +%Y-%m-%d,%H:%M:%S`
    if [ $exitCode -ne 0 ] ; then
        echo "$TIMESTMAP Failed to executing SPSS stream: $stream"
        echo ""
        exit 1
    fi
    echo "$TIMESTMAP Successfully finish executing: $stream"
    echo ""
}

# remove "^M" for all config files
cfgfiles=("$modelerServerCfg $streamOrderCfg $streamParamsCfg")
for cfgfile in ${cfgfiles[@]}
do
    linenum=`wc -l ${cfgfile} | awk '{print $1}'`
    linenum=`expr $linenum + 5`
    cp ${cfgfile} ${cfgfile}.bk
    head -${linenum} ${cfgfile}.bk | tr -d '\r' > ${cfgfile}
    rm -f ${cfgfile}.bk
done


while IFS='' read -r line || [[ -n "$line" ]]; do
    size=${#line}
    if [ $size -ne 0 ]; then
        executeStream $line
    fi
done < "$streamOrderCfg"

