-------------------------------------------------------------- 
-- Licensed Materials - Property of IBM
-- 
-- IBM Insights Foundation for Energy  5725-W39
--
-- (C) Copyright IBM Corp.  2016   All rights reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
-------------------------------------------------------------- 
--<ScriptOptions statementTerminator=";"/>

CREATE SCHEMA WIND;

CREATE TABLE WIND.Engineer (
		name VARCHAR(256), 
		id INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -2147483648 MAXVALUE 2147483647 NO CYCLE CACHE 20 NO ORDER ), 
		role VARCHAR(128)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.MaintenaceRequirement (
		id BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		resourceId BIGINT NOT NULL, 
		name VARCHAR(512) NOT NULL, 
		type VARCHAR(128) NOT NULL, 
		deadline DATE, 
		description VARCHAR(1024), 
		complete CHAR(1) NOT NULL, 
		duration DOUBLE, 
		instructions VARCHAR(2046), 
		material VARCHAR(1024)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.MaintenanceSchedule (
		id BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		createTime TIMESTAMP DEFAULT CURRENT TIMESTAMP, 
		powerloss DOUBLE, 
		productiongoal CHAR(1), 
		resourcegoal CHAR(1), 
		daygoal CHAR(1)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.MetAlt1Alt (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.MetAlt1Hum (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.MetAlt1Pres (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.MetAlt1Tmp (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.Power (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.PowerMV (
		timestamp TIMESTAMP, 
		value DOUBLE NOT NULL, 
		ID BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.PowerStatistic (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		Date DATE NOT NULL, 
		NetEnergy DOUBLE, 
		WeakEnergy DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.Region (
		OID BIGINT NOT NULL, 
		serialNumber CHAR(5) NOT NULL, 
		isActive CHAR(5), 
		installationDate CHAR(5), 
		removalData CHAR(5), 
		lastUpdateTime CHAR(5)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.ResourceSpecialVocation (
		id BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		vocationDate DATE, 
		workingDate DATE, 
		humanId INTEGER NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.ResourceWeeklyVocation (
		id BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		humanId INTEGER NOT NULL, 
		vocationDayInWeek INTEGER
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.StatusStatistic (
		MEASUREMENT BIGINT NOT NULL, 
		date DATE NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		stop DOUBLE, 
		running DOUBLE, 
		error DOUBLE, 
		lowpower DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.TURPOWER (
		MEASUREMENT BIGINT NOT NULL, 
		TIMESTAMP TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		VALUE DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.Table1 (
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.TruWindPowerStatistic (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		from TIMESTAMP NOT NULL, 
		to TIMESTAMP NOT NULL, 
		windspeed DOUBLE, 
		poweravg DOUBLE, 
		count BIGINT
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.TurSt (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		stVal SMALLINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.VArh (
		DmdVArh CHAR(5), 
		SupVArh CHAR(5), 
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WALM (
		timestamp TIMESTAMP NOT NULL, 
		Level SMALLINT NOT NULL, 
		ID BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		Description VARCHAR(1024), 
		Name VARCHAR(255) NOT NULL, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WCNV (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WGEN (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP, 
		manufacturer VARCHAR(200)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WMV (
		timestamp CHAR(5), 
		value DOUBLE NOT NULL, 
		ID BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WNAC (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WPP (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(1), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WPPFailureRecoveryStatistic (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		Date DATE NOT NULL, 
		MTBF DOUBLE, 
		MTTR DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WPPScore (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		overall DOUBLE, 
		convertrate DOUBLE, 
		healthscore DOUBLE, 
		power DOUBLE, 
		availability DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WROT (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP, 
		manufacturer VARCHAR(200)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WROT_data (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTOW (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTRF (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP, 
		manufacturer VARCHAR(200)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTRM (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTUR (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(1), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP, 
		powerRated FLOAT(5), 
		workwindspeed VARCHAR(100) NOT NULL DEFAULT '2m/s - 20m/s'
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTURScore (
		MEASUREMENT BIGINT NOT NULL, 
		TIMESTAMP TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		overall DOUBLE, 
		convertrate DOUBLE NOT NULL, 
		healthscore DOUBLE, 
		power DOUBLE, 
		availability DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTURSpd (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTURWdir (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE NOT NULL, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTURWspd (
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE NOT NULL, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTUR_ACCE_X (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTUR_ACCE_Y (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WTUR_YAW_DATA (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WYAW (
		OID BIGINT NOT NULL, 
		serialNumber VARCHAR(128) NOT NULL, 
		isActive CHAR(5), 
		installationDate DATE, 
		removalData DATE, 
		lastUpdateTime TIMESTAMP
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WYAWWdir (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WeatherForecast (
		id BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		date DATE, 
		narrative VARCHAR(1024), 
		windspeed DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WeatherHis (
		MEASUREMENT BIGINT NOT NULL, 
		Date DATE NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		Speed DOUBLE, 
		Directory DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WgenPower (
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WgenRiskStatistic (
		date DATE NOT NULL DEFAULT CURRENT DATE, 
		health DOUBLE, 
		failure DOUBLE, 
		MEASUREMENT BIGINT NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.Wh (
		DmdWh DOUBLE, 
		SupWh DOUBLE, 
		MEASUREMENT BIGINT NOT NULL, 
		timestamp TIMESTAMP NOT NULL
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WorkOrder (
		id BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE -9223372036854775808 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20 NO ORDER ), 
		humanId INTEGER NOT NULL, 
		scheduleId BIGINT NOT NULL, 
		requirementId BIGINT NOT NULL, 
		actionDate DATE NOT NULL, 
		description VARCHAR(1024), 
		feedback VARCHAR(1024)
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WrotRiskStatistic (
		MEASUREMENT BIGINT NOT NULL, 
		date DATE NOT NULL DEFAULT CURRENT DATE, 
		health DOUBLE, 
		failure DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WtrfRiskStatistic (
		MEASUREMENT BIGINT NOT NULL, 
		date DATE NOT NULL DEFAULT CURRENT DATE, 
		health DOUBLE, 
		failure DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

CREATE TABLE WIND.WturMaintenanceCost (
		Measurement BIGINT NOT NULL, 
		date TIMESTAMP NOT NULL, 
		value DOUBLE
	)
	DATA CAPTURE NONE 
	COMPRESS NO;

ALTER TABLE WIND.Engineer ADD CONSTRAINT Resource_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.MaintenaceRequirement ADD CONSTRAINT MaintenaceRequirement_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.MaintenanceSchedule ADD CONSTRAINT MaintenanceSchedule_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.MetAlt1Alt ADD CONSTRAINT MetAlt1Alt_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.MetAlt1Hum ADD CONSTRAINT MetAlt1Hum_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.MetAlt1Pres ADD CONSTRAINT MetAlt1Pres_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.MetAlt1Tmp ADD CONSTRAINT MetAlt1Tmp_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.Power ADD CONSTRAINT Power_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.PowerMV ADD CONSTRAINT MV_PK PRIMARY KEY
	(MEASUREMENT, 
	 ID);

ALTER TABLE WIND.PowerStatistic ADD CONSTRAINT PowerStatistic_PK PRIMARY KEY
	(MEASUREMENT, 
	 Date);

ALTER TABLE WIND.Region ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.ResourceSpecialVocation ADD CONSTRAINT ResourceSpecialVocation_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.ResourceWeeklyVocation ADD CONSTRAINT ResourceAvailability_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.StatusStatistic ADD CONSTRAINT StatusStatistic_PK PRIMARY KEY
	(MEASUREMENT, 
	 date);

ALTER TABLE WIND.TURPOWER ADD CONSTRAINT TurPower_PK PRIMARY KEY
	(MEASUREMENT, 
	 TIMESTAMP);

ALTER TABLE WIND.Table1 ADD CONSTRAINT Table1_PK PRIMARY KEY
	(MEASUREMENT);

ALTER TABLE WIND.TruWindPowerStatistic ADD CONSTRAINT Table1_PK PRIMARY KEY
	(MEASUREMENT, 
	 to, 
	 from);

ALTER TABLE WIND.TurSt ADD CONSTRAINT STV_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.VArh ADD CONSTRAINT VArh_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WALM ADD CONSTRAINT WALM_PK PRIMARY KEY
	(MEASUREMENT, 
	 ID, 
	 timestamp);

ALTER TABLE WIND.WCNV ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WGEN ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WMV ADD CONSTRAINT MV_PK PRIMARY KEY
	(MEASUREMENT, 
	 ID);

ALTER TABLE WIND.WNAC ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WPP ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WPPFailureRecoveryStatistic ADD CONSTRAINT WppFailureRecoveryStatistic_PK PRIMARY KEY
	(MEASUREMENT, 
	 Date);

ALTER TABLE WIND.WPPScore ADD CONSTRAINT WPPScore_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WROT ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WROT_data ADD CONSTRAINT Blade_data_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WTOW ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WTRF ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WTRM ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WTUR ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WTURScore ADD CONSTRAINT WTURScore_PK PRIMARY KEY
	(MEASUREMENT, 
	 TIMESTAMP);

ALTER TABLE WIND.WTURSpd ADD CONSTRAINT WTURSpd_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WTURWdir ADD CONSTRAINT MV_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WTURWspd ADD CONSTRAINT MV_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WTUR_ACCE_X ADD CONSTRAINT WTUR_ACCE_X_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WTUR_ACCE_Y ADD CONSTRAINT WTUR_ACCE_Y_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WTUR_YAW_DATA ADD CONSTRAINT WTUR_YUM_DATA_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WYAW ADD CONSTRAINT WTUR_PK PRIMARY KEY
	(OID, 
	 serialNumber);

ALTER TABLE WIND.WYAWWdir ADD CONSTRAINT YAWWspd_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WeatherForecast ADD CONSTRAINT WeatherForecast_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.WeatherHis ADD CONSTRAINT WeatherHis_PK PRIMARY KEY
	(MEASUREMENT, 
	 Date);

ALTER TABLE WIND.WgenPower ADD CONSTRAINT WgenPower_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WgenRiskStatistic ADD CONSTRAINT TruRiskStaticstic_PK PRIMARY KEY
	(MEASUREMENT, 
	 date);

ALTER TABLE WIND.Wh ADD CONSTRAINT Wh_PK PRIMARY KEY
	(MEASUREMENT, 
	 timestamp);

ALTER TABLE WIND.WorkOrder ADD CONSTRAINT WorkOrder_PK PRIMARY KEY
	(id);

ALTER TABLE WIND.WrotRiskStatistic ADD CONSTRAINT WrotRiskStatistic_PK PRIMARY KEY
	(MEASUREMENT, 
	 date);

ALTER TABLE WIND.WtrfRiskStatistic ADD CONSTRAINT WtrfRiskStatistic_PK PRIMARY KEY
	(MEASUREMENT, 
	 date);

ALTER TABLE WIND.WturMaintenanceCost ADD CONSTRAINT MaintenanceCost_PK PRIMARY KEY
	(Measurement, 
	 date);

ALTER TABLE WIND.MaintenaceRequirement ADD CONSTRAINT MaintenaceRequirement_RESOURCE_FK FOREIGN KEY
	(resourceId)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.MetAlt1Alt ADD CONSTRAINT MetAlt1Alt_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.MetAlt1Hum ADD CONSTRAINT MetAlt1Hum_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.MetAlt1Pres ADD CONSTRAINT MetAlt1Pres_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.MetAlt1Tmp ADD CONSTRAINT MetAlt1Tmp_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.Power ADD CONSTRAINT Power_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.PowerMV ADD CONSTRAINT PowerMV_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.PowerStatistic ADD CONSTRAINT PowerStatistic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.Region ADD CONSTRAINT Region_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.ResourceSpecialVocation ADD CONSTRAINT ResourceSpecialVocation_Resource_FK FOREIGN KEY
	(humanId)
	REFERENCES WIND.Engineer
	(id)
	ON DELETE CASCADE;

ALTER TABLE WIND.ResourceWeeklyVocation ADD CONSTRAINT ResourceWeeklyVocation_Resource_FK FOREIGN KEY
	(humanId)
	REFERENCES WIND.Engineer
	(id)
	ON DELETE CASCADE;

ALTER TABLE WIND.StatusStatistic ADD CONSTRAINT StatusStatistic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.TURPOWER ADD CONSTRAINT TurPower_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.Table1 ADD CONSTRAINT Table1_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.TruWindPowerStatistic ADD CONSTRAINT TruPowerStatistic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.TurSt ADD CONSTRAINT STV_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.VArh ADD CONSTRAINT VArh_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WALM ADD CONSTRAINT WALM_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WCNV ADD CONSTRAINT WCNV_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WGEN ADD CONSTRAINT WGEN_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WMV ADD CONSTRAINT WMV_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WNAC ADD CONSTRAINT WNAC_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WPP ADD CONSTRAINT WPP_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WPPFailureRecoveryStatistic ADD CONSTRAINT WppFailureRecoveryStatistic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WPPScore ADD CONSTRAINT WPPScore_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WROT ADD CONSTRAINT WROT_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WROT_data ADD CONSTRAINT Blade_data_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTOW ADD CONSTRAINT WTOW_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTRF ADD CONSTRAINT WTRF_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTRM ADD CONSTRAINT WTRM_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTUR ADD CONSTRAINT WTUR_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTURScore ADD CONSTRAINT WTURScore_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTURSpd ADD CONSTRAINT WTURSpd_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTURWdir ADD CONSTRAINT WdDirMV_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTURWspd ADD CONSTRAINT MV_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTUR_ACCE_X ADD CONSTRAINT WTUR_ACCE_X_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTUR_ACCE_Y ADD CONSTRAINT WTUR_ACCE_Y_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WTUR_YAW_DATA ADD CONSTRAINT WTUR_YUM_DATA_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WYAW ADD CONSTRAINT WYAW_RESOURCE_FK FOREIGN KEY
	(OID)
	REFERENCES CIM.RESOURCE
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WYAWWdir ADD CONSTRAINT YAWWspd_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WeatherHis ADD CONSTRAINT WeatherHis_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WgenPower ADD CONSTRAINT WgenPower_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WgenRiskStatistic ADD CONSTRAINT TruRiskStaticstic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.Wh ADD CONSTRAINT Wh_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WorkOrder ADD CONSTRAINT WorkOrder_MaintenaceRequirement_FK FOREIGN KEY
	(requirementId)
	REFERENCES WIND.MaintenaceRequirement
	(id)
	ON DELETE CASCADE;

ALTER TABLE WIND.WorkOrder ADD CONSTRAINT WorkOrder_MaintenanceSchedule_FK FOREIGN KEY
	(scheduleId)
	REFERENCES WIND.MaintenanceSchedule
	(id)
	ON DELETE CASCADE;

ALTER TABLE WIND.WorkOrder ADD CONSTRAINT WorkOrder_Resource_FK FOREIGN KEY
	(humanId)
	REFERENCES WIND.Engineer
	(id)
	ON DELETE CASCADE;

ALTER TABLE WIND.WrotRiskStatistic ADD CONSTRAINT WrotRiskStatistic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WtrfRiskStatistic ADD CONSTRAINT WtrfRiskStatistic_MEASUREMENT_FK FOREIGN KEY
	(MEASUREMENT)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;

ALTER TABLE WIND.WturMaintenanceCost ADD CONSTRAINT MaintenanceCost_MEASUREMENT_FK FOREIGN KEY
	(Measurement)
	REFERENCES CIM.MEASUREMENT
	(OID)
	ON DELETE CASCADE;
	
CREATE INDEX WIND.WTUR_ACCE_X_IDX
	ON WIND.WTUR_ACCE_X
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS YES;

CREATE INDEX WIND.WTUR_ACCE_Y_IDX
	ON WIND.WTUR_ACCE_Y
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS YES;
	
CREATE INDEX WIND.WROT_DATA_IDX
	ON WIND.WROT_DATA
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;

CREATE INDEX WIND.TURPOWER_IDX
	ON WIND.TURPOWER
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;
	
CREATE INDEX WIND.WTURSpd_IDX
	ON WIND.WTURSpd
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;
	
CREATE INDEX WIND.WTURWdir_IDX
	ON WIND.WTURWdir
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;

CREATE INDEX WIND.WTURWspd_IDX
	ON WIND.WTURWspd
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;
	
CREATE INDEX WIND.WTUR_YAW_DATA_IDX
	ON WIND.WTUR_YAW_DATA
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;
	
CREATE INDEX WIND.WYAWWdir_IDX
	ON WIND.WYAWWdir
	(TIMESTAMP		DESC)
	MINPCTUSED 0
	ALLOW REVERSE SCANS
	PAGE SPLIT SYMMETRIC
	COLLECT SAMPLED DETAILED STATISTICS
	COMPRESS NO;
	


GRANT ALTER ON TABLE WIND.MetAlt1Alt TO USER DB2INST1 WITH GRANT OPTION;

