package cognos;

import com.cognos.developer.schemas.bibus._3.AddOptions;
import com.cognos.developer.schemas.bibus._3.AnyTypeProp;
import com.cognos.developer.schemas.bibus._3.BaseClass;
import com.cognos.developer.schemas.bibus._3.BaseClassArrayProp;
import com.cognos.developer.schemas.bibus._3.ContentManagerService_PortType;
import com.cognos.developer.schemas.bibus._3.ContentManagerService_ServiceLocator;
import com.cognos.developer.schemas.bibus._3.DataSource;
import com.cognos.developer.schemas.bibus._3.DataSourceConnection;
import com.cognos.developer.schemas.bibus._3.DataSourceSignon;
import com.cognos.developer.schemas.bibus._3.Nil;
import com.cognos.developer.schemas.bibus._3.SearchPathSingleObject;
import com.cognos.developer.schemas.bibus._3.StringProp;
import com.cognos.developer.schemas.bibus._3.TokenProp;
import com.cognos.developer.schemas.bibus._3.UpdateActionEnum;
import java.net.URL;

public class Datasource {

	public ContentManagerService_PortType cmService = null;
	
	public void connectToReportServer(String endPoint) {
		// Create a connection to the Cognos service

		ContentManagerService_ServiceLocator cmServiceLocator = new ContentManagerService_ServiceLocator();

		try {
			cmService = cmServiceLocator
					.getcontentManagerService(new URL(endPoint));
		} catch (Exception e) {
			System.out.println(e);
		}

	}

	public void createDataSource(String dataSourceName,
			String dataSourceConnectionString, String dbuser, String dbpassword) throws Exception {
		DataSource dataSource = new DataSource();
		TokenProp tp = new TokenProp();
		tp.setValue(dataSourceName);
		dataSource.setDefaultName(tp);

		DataSourceConnection dataSourceConnection = new DataSourceConnection();
		dataSourceConnection.setDefaultName(tp);
		StringProp s = new StringProp();
		s.setValue(dataSourceConnectionString);
		dataSourceConnection.setConnectionString(s);
		
		DataSourceSignon dataSourceSignon = new DataSourceSignon();
		dataSourceSignon.setDefaultName(tp);
		
		BaseClassArrayProp cons = new BaseClassArrayProp();
		BaseClass[] oConsumers = new BaseClass [1];
		Nil c1 = new Nil();
		StringProp sp = new StringProp();
		//If you want a specific user/group to have access to the signon,
		//change the search path to that user/group search path
		sp.setValue("CAMID(\"::Everyone\")");
		c1.setSearchPath(sp);
		oConsumers[0] = c1;
		cons.setValue(oConsumers);
		//Set everyone to have access to the signon
		dataSourceSignon.setConsumers(cons);
				  
		//Add credentials to the signon 
		AnyTypeProp credentials = new AnyTypeProp();
		String credString="<credential><username>" + dbuser + "</username><password>" + dbpassword + "</password></credential>";
		credentials.setValue(credString);
		//Replace previous 3 lines with the next commented line,  
		//if you want to use the same credentials as another existing signon
		//credentials.setValue(dts); 
		dataSourceSignon.setCredentials(credentials);

		AddOptions addOptions = new AddOptions();
		addOptions.setUpdateAction(UpdateActionEnum.replace);

		// Create the data source
		cmService.add(new SearchPathSingleObject("CAMID(\":\")"),
				new BaseClass[] { dataSource }, addOptions);
		// Create the data source connection
		cmService.add(new SearchPathSingleObject(
				"CAMID(\":\")/dataSource[@name='" + dataSourceName + "']"),
				new BaseClass[] { dataSourceConnection }, addOptions);
		// Create the data source connection signon
		cmService.add(new SearchPathSingleObject(
				"CAMID(\":\")/dataSource[@name='" + dataSourceName + "']/dataSourceConnection[@name='" + dataSourceName + "']"),
				new BaseClass[] { dataSourceSignon }, addOptions);
	}

	public static void displayHelp() {
	        String usage = "";
	        usage += "Import the contents of a DataSource.\n\n";
	        usage += "Usage:\n\n";
	        usage += "-sDsN data source name\n\tData source name\n";
	        usage += "-UID db user ID\n\tdb User.\n";
	        usage += "-PWD db password\n\tdb password.\n";
	        usage += "-CONN conection string\n\texample jdbc:db2://9.161.81.194:60000.\n";
	        usage += "-DNS data source \n\texample pems_cl.\n";
	        usage += "-g CognosBIDispatcher\n\tDispatcher URL for Cognos BI.\n";
	        usage += "\t Default: http://localhost:9300/p2pd/servlet/dispatch\n";
	        System.out.println(usage);
	        System.exit(1);
	    }

	public static void main(String [] args) {
		String endPoint = "http://localhost:9300/p2pd/servlet/dispatch";
		String dataSourceName = "TIH_DS";
		//  ^User ID:^?Password:;LOCAL;D2;DSN=pems_cl;UID=%s;PWD=%s;jdbc:db2://9.161.81.194:60000@ASYNC=0@0/0@COLSEQ=
		//String dataSourceConnectionString = ";LOCAL;D2;DSN=pems_cl;UID=db2inst1;PWD=Pa88w0rd;jdbc:db2://9.161.81.194:60000@ASYNC=0@0/0@COLSEQ=";
		
	    String UID = null;
		String PWD = null;
		String CONN = null;
		String DNS = null;
		String connParams = "";
		int args_len = args.length ;
		
		if (args.length < 1){
            displayHelp();
            throw new IllegalArgumentException("No arguments provided. Enter appropriate arguments.");
        }
		
		for (int i=0; i<args_len; i++) {
           if (args[i].compareToIgnoreCase("-sDsN") == 0) {
               dataSourceName = args[++i];
           } else if (args[i].compareToIgnoreCase("-UID") == 0) {
               UID =  args[++i];       
           } else if (args[i].compareToIgnoreCase("-PWD") == 0) {
               PWD =  args[++i];       
           } else if (args[i].compareToIgnoreCase("-CONN") == 0) {
               CONN =  args[++i];
           } else if (args[i].compareToIgnoreCase("-DNS") == 0) {
               DNS =  args[++i];
           } else if (args[i].compareToIgnoreCase("-g") == 0) {
               endPoint =  args[++i];
           } else if (args[i].compareToIgnoreCase("-CONN_PARRMS") == 0) {
               connParams = args[(++i)];
           } else {
        	   displayHelp();
           }
       }
		
		String dataSourceConnectionString = "^User ID:^?Password:;LOCAL;D2;DSN=" + DNS + 
			";UID=" + UID + ";PWD=" + PWD + ";" + CONN + "@ASYNC=0@0/0@COLSEQ=" +
			"IBM_JD_CNX_STR:^User ID:^?Password:;LOCAL;JD-D2;URL=" + CONN + "/" + DNS + ";DRIVER_NAME=com.ibm.db2.jcc.DB2Driver" + ";" + connParams;

		Datasource security = new Datasource();
		System.out.println(dataSourceConnectionString);
		System.out.println(endPoint);
	
		security.connectToReportServer(endPoint);
		try {
			security.createDataSource(dataSourceName,dataSourceConnectionString, UID, PWD);
			System.out.println("Done.Data source is created successfully.");
		} catch (Exception ex) {
			System.out.println("\nAn error occurred\n");
			ex.printStackTrace();
		}
	}
}
