# \author Ulrich Finkler, Amith Singhee


# gather all .C and .c files and strip extension to build programs
PROGRAMS :=  $(patsubst %.cpp,@_@$(AOMS_MAKE_PLATFORM)%,$(wildcard *.cpp)) $(patsubst %.C,@_@$(AOMS_MAKE_PLATFORM)%,$(wildcard *.C)) $(patsubst %.c,@_@$(AOMS_MAKE_PLATFORM)%,$(wildcard *.c))
BEAMS :=  $(patsubst %.cpp,@_@$(AOMS_MAKE_PLATFORM)%.beam,$(wildcard *.cpp)) $(patsubst %.C,@_@$(AOMS_MAKE_PLATFORM)%.beam,$(wildcard *.C)) $(patsubst %.c,@_@$(AOMS_MAKE_PLATFORM)%.beam,$(wildcard *.c))

NL_TMP := $(patsubst $(AOMS_BASE)/src/C/Libs/%/,%,$(wildcard $(AOMS_BASE)/src/C/Libs/*/))
U_LIBR := $(foreach lib, $(filter-out CVS,$(NL_TMP)), $(AOMS_BASE)/src/C/Libs/$(lib)/@_@$(AOMS_MAKE_PLATFORM)lib$(lib).a)
UC_I   := -I $(AOMS_BASE)/src/C/Libs $(foreach lib, $(filter-out CVS,$(NL_TMP)), -I $(AOMS_BASE)/src/C/Libs/$(lib)/ )

ML_TMP  := $(patsubst $(AOMS_BASE)/lib/C/%/,%,$(wildcard $(AOMS_BASE)/lib/C/*/))
UC_I    := $(UC_I) $(foreach lib, $(filter-out CVS,$(ML_TMP)), -I $(AOMS_BASE)/lib/C/$(lib)/Includes/ )

EL_TMP  := $(patsubst $(AOMS_BASE)/lib/C/%/Statlibs,%,$(wildcard $(AOMS_BASE)/lib/C/*/Statlibs))
U_ELIBR := $(foreach lib, $(filter-out CVS,$(EL_TMP)), $(AOMS_BASE)/lib/C/$(lib)/Statlibs/@_@$(AOMS_MAKE_PLATFORM)/*.a)

# Collect all the shared objects names for linking.
# Create -l flag so list from src/C/Build where all the
# shared objects were softlinked in by "make setup"
# NOTE:
# This mechanism does not allow the developer to use multiple
# versions of a single shared library since all those versions
# would be soft-linked to the same place. To allow multiple versions,
# there are two future options:
# 1. Use explicit paths to original shared object files, instead
#   of collecting soft-links in one location. But this would hard-code
#   the paths in the generated binary, and the .so files would have
#   to be in same location during "run" and "deploy" as they were
#   during build. To make this seamless, we might soft-link all the
#   library *folders* (lib/C/<blah>) to a fixed location like /opt/ibm/aoms/lib.
# 2. For each case of conflicting versions, the developer would have to
#   wrap at least one of the versions in his/her own .so and hide
#   the symbols in a versioned namespace, possibly using the version-script
#   trick on 'ld'.
SL_TMP  := $(patsubst $(AOMS_BASE)/lib/C/%/Sharedlibs,%,$(wildcard $(AOMS_BASE)/lib/C/*/Sharedlibs))
U_SLIBR := $(patsubst $(AOMS_BASE)/src/C/Build/$(AOMS_MAKE_PLATFORM)/Liblinks/lib%.so,-l%,$(wildcard $(AOMS_BASE)/src/C/Build/$(AOMS_MAKE_PLATFORM)/Liblinks/*.so))
override AOMS_MAKE_LDFLAGS := $(AOMS_MAKE_LDFLAGS) -L $(AOMS_BASE)/src/C/Build/$(AOMS_MAKE_PLATFORM)/Liblinks

.PHONY: all clean depend proper programs_final beam clean_beam

all:
	+ $(MAKE) programs_final

clean: clean_beam
	rm -f $(PROGRAMS)
	rm -f @_@$(AOMS_MAKE_PLATFORM)*.o
	rm -f @_@$(AOMS_MAKE_PLATFORM)*.a
	rm -f @_@$(AOMS_MAKE_PLATFORM)DEPENDENCIES

depend: 
	$(AOMS_MAKE_DEPEND)| sed 's/^.*\.o:/@_@$(AOMS_MAKE_PLATFORM)&/' > @_@$(AOMS_MAKE_PLATFORM)DEPENDENCIES
	for V in $(PROGRAMS); do echo $$V: $(U_LIBR)  >> @_@$(AOMS_MAKE_PLATFORM)DEPENDENCIES; done

proper: clean
	rm -f Makefile
	rm -f @_@*

clean_beam:
	rm -f *.beam *.complaint
	rm -f $(BEAMS) *.stats *.complaint

programs_final: $(PROGRAMS)

# enforces a 'make' in the library directory. 
%.a: FORCE
	+ cd $(AOMS_BASE)/src/C/Libs/$(patsubst @_@$(AOMS_MAKE_PLATFORM)lib%.a,%,$(@F)); $(MAKE) LIBRARY=$(patsubst @_@$(AOMS_MAKE_PLATFORM)lib%.a,%,$(@F))

FORCE:

-include @_@$(AOMS_MAKE_PLATFORM)DEPENDENCIES


include $(AOMS_BASE)/src/C/Makefiles/implicit.makefile
beam : $(BEAMS)
	echo "BEAMS $(BEAMS)"
