# Author: Ulrich Finkler, Amith Singhee, Ashish Sabharwal
BUILDDIR := $(AOMS_BASE)/src/Streams/Build
BUILDDIR_PF := $(BUILDDIR)/$(AOMS_MAKE_PLATFORM)

# Include all the libraries within start-group, end-group because
# Streams does not use start/end-group to allow for cyclic symbol dependencies
# Additionally, use the full file paths instead of -l flags to allow for
# multiple versions of the same library. An example is the icu libs: Cplex12.4
# wants icu4.2, while Streams2/3 want icu4.4 and the way sc organizes the lib paths
# in the linker command can cause the linker to ignore the seconds libicu (v4.2)
# if it already sees the first libicu (v4.4) and this can cause symbol
# not found errors during link.
EL_LDFLAGS := -Wl,-rpath,$(AOMS_BASE)/src/Streams/Build/$(AOMS_MAKE_PLATFORM)/Liblinks $(AOMS_MAKE_LGSTART) $(wildcard $(AOMS_BASE)/src/Streams/Build/$(AOMS_MAKE_PLATFORM)/Liblinks/*.a) $(wildcard $(AOMS_BASE)/src/Streams/Build/$(AOMS_MAKE_PLATFORM)/Liblinks/*.so)  $(AOMS_MAKE_LGEND)

TOOLKIT_TMP := $(patsubst $(AOMS_BASE)/lib/Streams/%/,%,$(wildcard $(AOMS_BASE)/lib/Streams/*/))
TOOLKIT_PATH := $(foreach lib, $(filter-out CVS,$(TOOLKIT_TMP)), $(AOMS_BASE)/lib/Streams/$(lib))
TOOLKIT_INT := $(patsubst $(AOMS_BASE)/src/Streams/Toolkits/%/,%,$(wildcard $(AOMS_BASE)/src/Streams/Toolkits/*/))
TOOLKIT_PATH := $(foreach lib, $(filter-out CVS,$(TOOLKIT_INT)),$(AOMS_BASE)/src/Streams/Toolkits/$(lib)) $(TOOLKIT_PATH)
TOOLKIT_PATH := $(wildcard $(STREAMS_INSTALL)/toolkits/com.ibm.streams.*) $(TOOLKIT_PATH)
TOOLKIT_PATH := $(subst $(eval) ,:,$(strip $(TOOLKIT_PATH)))
TOOLKITFLAG=
ifneq ($(strip $(TOOLKIT_PATH)),)
	TOOLKITFLAG=-t $(TOOLKIT_PATH)
endif

DISTRIBUTED_ADLFILES := $(shell find . -mindepth 1 -maxdepth 1 -type d -not -wholename "*CVS" -not -wholename "." -not -wholename "*data" -not -wholename "*output" -not -wholename "*impl"   -not -wholename "./*.*" -exec find  {} -name "*.spl" \; | sed 's:^\.\/\(.*\)/\(.*\).spl:output/\1.\2/Distributed/\1.\2.adl:')
STANDALONE_ADLFILES := $(shell find . -mindepth 1 -maxdepth 1 -type d -not -wholename "*CVS" -not -wholename "." -not -wholename "*data" -not -wholename "*output" -not -wholename "*impl"   -not -wholename "./*.*" -exec find  {} -name "*.spl" \; | sed 's:^\.\/\(.*\)/\(.*\).spl:output/\1.\2/Standalone/\1.\2.adl:')


build: depend $(DISTRIBUTED_ADLFILES)
	#echo "Distributed" $(DISTRIBUTED_ADLFILES)
	spl-make-toolkit -i .

build_standalone: depend $(STANDALONE_ADLFILES)
	#echo "Standalone" $(STANDALONE_ADLFILES)
	spl-make-toolkit -i .

%.adl:
	#echo "Here " $@
	-MAIN_COMPOSITE_NAME=$(shell echo $@ | sed 's:^output/\(.*\)\.\(.*\)/\(.*\)/\1\.\2\.adl:\1\:\:\2:') ; OUTPUT_DIRECTORY=$(shell dirname $@) ; STANDALONE=$(shell echo $@ | sed -e 's/.*Distributed.*//' -e 's/.*Standalone.*/-T/') ; sc $(TOOLKITFLAG) -s $$STANDALONE -M $$MAIN_COMPOSITE_NAME --output-directory=$$OUTPUT_DIRECTORY --data-directory=data --no-mixed-mode-preprocessing --ld-flags="$(EL_LDFLAGS) $(AOMS_MAKE_LDFLAGS)" --cxx-flags="$(AOMS_MAKE_CFLAGS)";

clean: 
	@for i in `find . -mindepth 1 -maxdepth 1 -type d -not -wholename "*CVS" -not -wholename "." -not -wholename "*data" -not -wholename "*output" -not -wholename "*impl"   -not -wholename "./*.*" `; do\
	  echo $$i;\
	  for j in `find $$i -mindepth 1 -maxdepth 1 -type f -name "*.spl"`; do \
            N=$$(basename $$j); \
            M=$${N%.*}; \
	    C="sc -C -M $$(basename $$i)::$$M" ;\
	    echo $$C;\
	    $$C;\
	  done;\
	done
	@for f in `find . -name "*.cgt" | sed "s/\.cgt/.pm/g"`; do \
		if [ -f $$f ]; then \
            C="rm $$f"; \
            echo $$C; \
            eval $$C; \
		fi \
	done
	@rm -rf output
	@rm -rf data
	@rm -rf toolkit.xml
	@rm -rf .project
	@rm -rf .settings
	@rm -f depend
#	MAIN_COMPOSITE_NAME=$(shell echo $@ | sed 's:^output/\(.*\)\.\(.*\)/\(.*\)/\1\.\2\.adl:\1\:\:\2:') ; \	
#	OUTPUT_DIRECTORY=$(shell dirname $@) ;
-include depend
depend : 
	rm -f depend ; touch depend
	echo "### Do not modify this file manually, it is been created automatically and will be overwritten" >> depend
	for adlfile in $(STANDALONE_ADLFILES) $(DISTRIBUTED_ADLFILES) ; do splfile=$$(echo $$adlfile | sed 's:^output/\(.*\)\.\(.*\)/\(.*\)/\1\.\2\.adl:\1\/\2\.spl:') ; echo "$$adlfile : $$splfile" >> depend; echo "$$adlfile : .FORCE" >> depend; done
## target .FORCE is used for forced build: if one adds a line
## "the target" : .FORCE   
## "the target" will always rebuild because .FORCE is never created
## we supply necessary dependencies for ADL builds in  file depend above
.PHONY : .FORCE
.FORCE :
 
