#!/bin/bash

##
# Licensed Materials - Property of IBM
#
# IBM Insights Foundation for Energy  5725-W39
#
# (C) Copyright IBM Corp. 2015  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
## 

if [ $# -ne 4 ]; then
	echo "Usage: $0 <serviceUrl> <username> <password> <assetClassCodeList>"
	exit 1
fi

serviceUrl=$1
username=$2
password=$3
assetClassCodeList=$4

CURL="curl -s -k -u $username:$password"

#read config props from properties file
#username=`sed '/^\#/d' "config.props" | grep "username"  | tail -n 1 | cut -d "=" -f2-`
#password=`sed '/^\#/d' "config.props" | grep "password"  | tail -n 1 | cut -d "=" -f2-`
#assetClassCodeList=`sed '/^\#/d' "config.props" | grep "assetClassCodeList"  | tail -n 1 | cut -d "=" -f2-`
#serviceUrl =`sed '/^\#/d' "config.props" | grep "serviceUrl"  | tail -n 1 | cut -d "=" -f2-`

# for each asset class in list
assetClassArray=$(echo $assetClassCodeList | tr "," "\n")

for assetClassCode in $assetClassArray
do
	echo " === executing analysis for asset class" $assetClassCode "==="
	#get asset class id with asset class code
	#assetClassId=`$CURL $serviceUrl/assetClassId?assetClassCode=$assetClassCode | grep ID | awk 'BEGIN {FS = "\"ID\":"} {print substr($2,1,index($2,"}")-1)}'`
	
	#get all active package id list with asset class code
	serviceRes=`$CURL $serviceUrl/packageIdList?assetClassCode=$assetClassCode`
	packageArray=(${serviceRes//},/ })
	# for each package id in the array
	for element in "${packageArray[@]}"
	do
		packageId=`echo $element | grep package_id | awk 'BEGIN {FS = "\"package_id\":"} {print substr($2,1,index($2,"}")-1)}'`
		if [ "${#packageId} " -ne 0 ]
		then 
			# invoke AHA analysis with package id
			echo " === executing analysis for package " $packageId "=== "
			$CURL -X POST -H 'Content-Type: application/json' $serviceUrl/analysis/$packageId/scoring -d "[]"
	
			# sleep before get analysis current status
			sleep 20

			# get analysis status
			status=`$CURL $serviceUrl/analysis/$packageId/status | grep STATUS | awk  'BEGIN {FS = "STATUS\":\""} {print substr($2,0,index($2,"\"")-1)}'`
			while [ "$status" == "Started" ] || [ "$status" == "Open" ]
			do	
				sleep 20
				status=`$CURL $serviceUrl/analysis/$packageId/status | grep STATUS | awk  'BEGIN {FS = "STATUS\":\""} {print substr($2,0,index($2,"\"")-1)}'`
			done
			echo $status
		
			if [ "$status" == "Failed" ]
			then 
				echo "analysis failed"
				echo "please log on database, and refer AHA.VALIDATION table for more detail information."
				exit 1
			fi
		fi
	done
done

exit 0
