#!/bin/bash

##
# Licensed Materials - Property of IBM
#
# IBM Insights Foundation for Energy  5725-W39
#
# (C) Copyright IBM Corp. 2015  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
## 

#SOURCE="${BASH_SOURCE[0]}"
#SOURCE_DIR="$( dirname "$SOURCE" )"

#cd $SOURCE_DIR
#SOURCE_DIR=`pwd`

# Register signal handler for Ctrl+C
trap "catalog_cleanup;exit 2" INT

#echo "The tool is used to configure database on the master node"
#echo ""
#echo "================================================================================================"
#echo "Enter the following 7 configuration parameters followed by the instructions"
#echo "Don't worry if you input incorrect value, you have chance to correct it till everything is OK"
#echo "You can exit via Ctrl+C if it's not finished, this tool will cleanup the incomplete catalog info"
#echo "================================================================================================"
#echo ""

function catalog_cleanup(){
  if [[ -z $db_nodename ]] && [[ -z $db_alias ]];then
    echo ""
    echo "No incomplete catalog info left. Done"
    echo ""
    exit 2  # This exit code will be used by caller script, please take care when modifying it
  fi

  echo ""
  echo "Do cleanup ..."

  if [[ -n $db_nodename ]];then
    echo "$DB2 uncatalog node $db_nodename"
    cmd=`$DB2 uncatalog node $db_nodename`
    echo ""
  fi

  if [[ -n $db_alias ]];then
    echo "$DB2 uncatalog database $db_alias"
    cmd=`$DB2 uncatalog database $db_alias`
    echo ""
  fi

  echo "Done"
  echo ""
}

function catalog_step1_recover(){
  db_hostname=""
  db_port=""
  cmd=`$DB2 uncatalog node $db_nodename`
  catalog_step1
}

function catalog_step2_recover(){
  db_name=""
  cmd=`$DB2 uncatalog database $db_alias`
  catalog_step2
}

function catalog_step3_recover(){
  db_userid=""
  db_passwd=""
  catalog_step3
}

function connect_failed_recover(){

  steps=3
  for (( i=1; i <= $steps; i++)); do

    case $i in
      "1") msg="db hostname/ip/port";;
      "2") msg="db name";;
      "3") msg="db user/password";;
    esac

    echo ""
    echo "Is $msg correct [y/n]?"
    isParamCorrect=""
    while [[ "$isParamCorrect" == "" ]]; do
      read -p "Your choice: " isParamCorrect
      if [[ "$isParamCorrect" == "y"  ]];then
        break
      elif [[ "$isParamCorrect" == "n" ]];then
        catalog_step${i}_recover
      else
        isParamCorrect=""
      fi
    done # while
  done # for
}

function catalog_step1(){

  echo ""
  echo "catalog step 1"

  retCode=""
  while [[ $retCode != "0" ]];do

    while [[ "$db_hostname" == "" ]]; do
      read -p "Please enter db2 server hostname/ip: " db_hostname
    done

    while [[ "$db_port" == "" ]]; do
      read -p "Please enter db2 server port: " db_port
    done

    default_db_nodename=DB_Node
    while [[ "$db_nodename" == "" ]]; do
      read -p "Please enter the database catalog node name [$default_db_nodename]: " db_nodename
      if [[ "$db_nodename" == "" ]];then
        echo "Default database node name [$default_db_nodename] is used"
        db_nodename=$default_db_nodename
      fi
    done

    cmd=`$DB2 catalog tcpip node $db_nodename remote $db_hostname server $db_port`
    retCode=$?
    if [[ $retCode != "0"  ]];then
      echo "catalog node failed, please check and config again"
      echo "Error msg: \"$cmd\""
      db_hostname=""
      db_port=""
      db_nodename=""
    fi

  done

  echo ""
  echo "$DB2 catalog tcpip node $db_nodename remote $db_hostname server $db_port"
  echo "Congratulations, catalog step 1 sucessfully completed!"
}

function catalog_step2(){

  echo ""
  echo "catalog step 2"

  retCode=""
  while [[ $retCode != "0" ]];do

    default_db_name=IFEDB
    while [[ "$db_name" == "" ]]; do
      read -p "Please enter database name [$default_db_name]: " db_name
      if [[ "$db_name" == "" ]]; then
        echo "Default database name [$default_db_name] is used"
        db_name=$default_db_name
      fi
    done

    default_db_alias=IFEDB
    while [[ "$db_alias" == "" ]]; do
      read -p "Please enter database catalog alias name [$default_db_alias]: " db_alias
      if [[ "$db_alias" == "" ]]; then
        echo "Default database alias name [$default_db_alias] is used"
        db_alias=$default_db_alias
      fi
    done

    cmd=`$DB2 catalog database $db_name as $db_alias at node $db_nodename`
    retCode=$?
    if [[ $retCode != 0  ]];then
      echo "catalog alias failed, please check and config again"
      echo ""
      echo "Error msg: \"$cmd\""
      db_name=""
      db_alias=""
    fi

  done

  echo ""
  echo "$DB2 catalog database $db_name as $db_alias at node $db_nodename"
  echo "Congratulations, catalog step 2 sucessfully completed!"
}

function catalog_step3(){

  echo ""
  echo "catalog step 3"

  while [[ "$db_userid" == "" ]]; do
    read -p "Please enter database user id: " db_userid
  done

  stty -echo
  while [[ "$db_passwd" == "" ]]; do
    read -p "Please enter database password: " db_passwd
  done
  stty echo
}

function connectivity_verify(){

  echo ""
  echo "Connectivity verify"

  retCode=""
  while [[ $retCode != "0" ]];do
    echo ""
    echo "Refresh CLP's directory cache before connect to cataloged database"
    cmd=`$DB2 terminate`
    retCode=$?
    if [[ $retCode == "0"  ]];then
      echo "CLP's directory cache refresh successfully."
    else
      echo "CLP's directory cache refresh failed."
      echo "If the following connection step also failed, please exit(Ctrl+C) and rerun me"
    fi
    echo ""

    retCode=""
    cmd=`$DB2 connect to $db_alias user $db_userid using $db_passwd`
    retCode=$?

    if [[ $retCode != "0"  ]];then
      echo "connect failed, please check and follow the instructions to config again"
      echo "Error msg: \"$cmd\""
      connect_failed_recover
      retCode=""
    else
      break
    fi
  done

  echo ""
  echo ""
  echo "Congratulations, connectivity test sucessfully!"
  cmd=`$DB2 connect reset`
}

function gene_cfg(){
  echo "dbuser=$db_userid" > $database_file
  echo "dbpasswd=$db_passwd" >> $database_file
  echo "dsname=$db_alias" >> $database_file
}

######################### main

if [ $# != 2 ] ; then
  echo "Please input correct parameters"
  echo "Usage: $0 $DB2INVOKER $tmpcfgfile"
  echo "e.g. $0 /home/db2inst1/sqllib/bin/db2 /tmp/database"
  exit 1
fi

DB2=$1
database_file=$2

if [[ ! -w $database_file ]];then
  echo ""
  echo "`whoami` have no permission to write file $database_file"
  echo "Please check and rerun me"
  echo ""
  exit 1
fi 

# we need $DB2 user to config catalog 
catalog_step1
catalog_step2
catalog_step3
connectivity_verify

gene_cfg

exit 0
