#!/bin/bash

##
# Licensed Materials - Property of IBM
#
# IBM Insights Foundation for Energy  5725-W39
#
# (C) Copyright IBM Corp. 2015  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
## 

SOURCE="${BASH_SOURCE[0]}"
SOURCE_DIR="$( dirname "$SOURCE" )"

cd $SOURCE_DIR
SOURCE_DIR=`pwd`

echo "The tool is used to configure grid engine"
echo ""
echo "================================================================================"
echo "Please follow the instructions to enter the 8 configuration parameters"
echo "Don't worry if input is incorrect, the tool will guide you till everything is OK"
echo "If you terminate the tool via Ctrl+C, incomplete catalog info will be cleaned"
echo "================================================================================"
echo ""

function Init(){

  cfg_file=$SOURCE_DIR/../grid_engine.cfg
  if [[ -f $cfg_file ]];then
    echo "$cfg_file already exist, do you want to overwrite it [y/n]?"
    while [[ "$reconfig" == "" ]]; do
      read -p "Your choice: " reconfig
      if [[ "$reconfig" == "y"  ]];then
        break
      elif [[ "$reconfig" == "n" ]];then
        echo "Existed file $cfg_file is used"
        exit 0
      else
        reconfig=""
      fi
    done

    if [[ ! -w $cfg_file ]];then
      echo ""
      echo "`whoami` have no permission to write file $cfg_file"
      echo "Please check and rerun me"
      echo ""
      exit 1
    fi
  else # if [[ -f $cfg_file ]];then
    # if $cfg_file doesn't exist, then try to create one
    touch $cfg_file
    if [[ $? != "0" ]];then
      echo ""
      echo "`whoami` have no permission to create file $cfg_file to store config information"
      echo "Please check and rerun"
      echo ""
      exit 1
    fi
  fi

  # current script is executed by root, but we need db2 user(e.g. db2inst1) to run $db2instexe
  default_db2inst=db2inst1
  while [[ "$DB2INST" == "" ]]; do
    read -p "Please input db2 user name [$default_db2inst]: " DB2INST
      if [[ "$DB2INST" == "" ]];then
        echo "Default db2 user name [$default_db2inst] is used"
        DB2INST=$default_db2inst
      fi
  done

}

######################### main

Init

db2instexe=$SOURCE_DIR/database.sh
tmpcfgfile="/tmp/grid_engine.database.$$"

# create the tmporary config file and assign the write permission to other users
touch $tmpcfgfile
chmod 666 $tmpcfgfile

# Need '-' before $DB2INST to switch to db2 user (We need db2 env ready before get db2 information)
DB2INVOKER=`su - $DB2INST -c "which db2"`
retCode=$?
if [[ $retCode != "0" ]];then
  echo "$DB2INVOKER"
  echo "su - $DB2INST -c \"which db2\" failed, please check"
  exit 1
fi

# Note for below 'su' command:
# 1. Need '-' before $DB2INST to switch to db2 user (We need db2 env ready before run db2 command)
# 2. Use --session-command (not -c), then Ctrl+C can be catched by $db2instexe, then do cleanup there
# 3. Don't use something like: cmd=`su $DB2INST --session-command="$db2instexe"`,
#    because we need to see 'echo' info emitted by $db2instexe 
su - $DB2INST --session-command="sh $db2instexe $DB2INVOKER $tmpcfgfile"
retCode=$?

# $tmpcfgfile will be 'mv' to $database_file, don't need to remove
if [[ $retCode == "0" ]];then

  # set readonly permission to other users
  chmod 644 $tmpcfgfile
  mv $tmpcfgfile $cfg_file
  
  default_port=16088
  read -p "Please enter port number[$default_port]: " $port
  if [[ $port == ""  ]];then
  	port=$default_port
  fi  
 
  echo "DB2_DIR=$(ls -d ~$DB2INST)"
  echo "port=$port" >> $cfg_file  

  echo ""
  echo "The generated config file is: $cfg_file"
  echo ""
  echo "==========================================================================="
  echo "Finish the configuration of grid engine"
  echo "==========================================================================="
  echo ""
elif [[ $retCode == "2" ]];then
  echo "Terminated by Ctrl+C, exit" 
  exit $retCode
else
  echo "config failed"
  exit 1
fi

exit 0
