#!/bin/bash

##
# Licensed Materials - Property of IBM
#
# IBM Insights Foundation for Energy  5725-W39
#
# (C) Copyright IBM Corp. 2015  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
## 

# To set up the env and build the package in RHEL 6.*
# Usage: aoms-bordeaux-build <full-root-path> [dist-root-path]

if [[ $# -ne 1 && $# -ne 2 ]]; then
	echo "Usage: $0 <full-path as package root> [dist directory]"
	exit 1;
fi

bordeaux_root=$1
if [ -d "${bordeaux_root}" ]; then
	echo "root-path = ${bordeaux_root}"
else
	echo "Directory ${bordeaux_root} does not exist. Please check the root path"
	exit 1;
fi

if [ $# -eq 1 ]; then
	dist_root=${bordeaux_root}/dist	
else
	dist_root=$2
fi

dist_root=$dist_root/ife_aoms_core

if [ ! -d "${dist_root}" ]; then
	mkdir -p ${dist_root}	
else
	echo "Clean dist_root ${dist_root}"
	rm -rf ${dist_root}/*
fi
echo "dist_root = ${dist_root}"

echo "====================================="
echo " Starting the dist for grid-engine..."
echo "====================================="
cd ${bordeaux_root}
export AOMS_ENV_ROOT="$PWD"
export PATH="$PATH:$AOMS_ENV_ROOT/bin"
cp src/aoms-bordeaux/scripts/aomsprofile.sh scripts
source "$AOMS_ENV_ROOT/scripts/aomsprofile.sh"

cp --dereference -rf $AOMS_ENV_ROOT/bin $AOMS_ENV_ROOT/pkgs $AOMS_ENV_ROOT/scripts ${dist_root}
rm -rf ${dist_root}/scripts/.jazzignore

pkg_name=aoms-grid-service
cd $AOMS_ENV_ROOT/src/${pkg_name}
tar --exclude .jazzignore --exclude .gitignore --exclude *.o --exclude *~ --exclude *.java --exclude *.cpp --exclude *.h --exclude *.hpp --exclude *.incl --exclude *.y --exclude *.l --exclude *.mk --exclude Makefile -h -cvf ${dist_root}/${pkg_name}.tar bin config scripts src/C/Libs src/C/Progs src/C/Scripts package.conf
pkg_dir=${dist_root}/src/${pkg_name}
mkdir -p ${pkg_dir}
tar -xvf ${dist_root}/${pkg_name}.tar -C ${pkg_dir}
rm -rf ${dist_root}/${pkg_name}.tar

pkg_name=aoms-cfp
cd $AOMS_ENV_ROOT/src/${pkg_name}
tar --exclude .jazzignore --exclude .gitignore --exclude *.o --exclude *~ --exclude *.java --exclude *.cpp --exclude *.h --exclude *.hpp --exclude *.incl --exclude *.y --exclude *.l --exclude *.mk --exclude Makefile -h -cvf ${dist_root}/${pkg_name}.tar bin config scripts src/C/Libs src/C/Progs src/C/Scripts package.conf
pkg_dir=${dist_root}/src/${pkg_name}
mkdir -p ${pkg_dir}
tar -xvf ${dist_root}/${pkg_name}.tar -C ${pkg_dir}
rm -rf ${dist_root}/${pkg_name}.tar

pkg_name=aoms-utl
cd $AOMS_ENV_ROOT/src/${pkg_name}
tar --exclude .jazzignore --exclude .gitignore --exclude *.o --exclude *~ --exclude *.java --exclude *.cpp --exclude *.h --exclude *.hpp --exclude *.incl --exclude *.y --exclude *.l --exclude *.mk --exclude Makefile -h -cvf ${dist_root}/${pkg_name}.tar src/Java 
pkg_dir=${dist_root}/src/${pkg_name}
mkdir -p ${pkg_dir}
tar -xvf ${dist_root}/${pkg_name}.tar -C ${pkg_dir}
rm -rf ${dist_root}/${pkg_name}.tar

#cp -rf $AOMS_ENV_ROOT/src/aoms-bordeaux ${dist_root}/src

cd ${dist_root}/..
tar -zcvf ife_aoms_core.tar.gz ife_aoms_core

echo "====================================="
echo " Finished the dist for grid-engine"
echo "====================================="
