#!/bin/bash

##
# Licensed Materials - Property of IBM
#
# IBM Insights Foundation for Energy  5725-W39
#
# (C) Copyright IBM Corp. 2015  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
## 

SOURCE="${BASH_SOURCE[0]}"
DIR="$( dirname "$SOURCE" )"

cd $DIR/..
export AOMS_ENV_ROOT="$PWD"

function usage() {
	echo "Usage: $0 [-c cfg file] start|stop|restart"
}

CFG_FILE=$AOMS_ENV_ROOT/scripts/grid_engine.cfg
while getopts 'c:' OPTION
do
  case $OPTION in
  c)	CFG_FILE="$OPTARG";;
  ?)	usage
  		exit 1;;
  esac
done
shift $(($OPTIND - 1))

if [ ! -f $CFG_FILE ]
then
    echo "Error: the configuration file $CFG_FILE does not exist, please specify the correct configuration file!"
    exit 1 #exit the sript
fi

ACTION=$*

function _start() {
	export PATH=$AOMS_ENV_ROOT/bin:$PATH
	
	source $AOMS_ENV_ROOT/scripts/aomsprofile.sh 
	
	local aoms_package=aoms-grid-service
	cd $AOMS_ENV_ROOT/src/$aoms_package
	source aoms-make-setupenv $PWD --force
	
	PROPERTIES_FILE=$CFG_FILE
	source $AOMS_ENV_ROOT/scripts/property.inc
	
	source_property DB2_DIR
	source_property port
	source_property dbuser
	dbpasswd=$($AOMS_ENV_ROOT/scripts/utils/password.sh -d $PROPERTIES_FILE dbpasswd)
	if [ $? -ne 0 ]; then
		echo "Error: wrong encoded database password"
		exit 1
	fi
	source_property dsname
	
	# The env var DB2_DIR should be defined 
	[ "$DB2_DIR" ] || DB2_DIR=/home/db2inst1 
	source $DB2_DIR/sqllib/db2profile
	
	source aoms-builder-setbase
	
	export AOMS_DB2_SCHEMA=CIM

	echo "##################################################################"
	echo "# Starting Grid Engine server..."
	echo "##################################################################"
	local TIMESTMAP=`date +%Y%m%dT%H-%M-%S`
	local LOG_DIR=$AOMS_ENV_ROOT/scripts/logs
	mkdir -p $LOG_DIR
	local LOG_FILE=$LOG_DIR/run_grid_engine_${TIMESTMAP}.log
	MAIN_ARGS="-db $dsname:$dbuser:$dbpasswd $port"
	if [ -z "$DEBUGGER" ] ; then
	    $AOMS_BASE/../aoms-grid-service/src/C/Progs/SocketServer/@_@g++64_GridServiceMultiplexSocketServer $MAIN_ARGS >$LOG_FILE 2>&1 &
	else
	    eval $DEBUGGER $AOMS_BASE/../aoms-grid-service/src/C/Progs/SocketServer/@_@g++64_GridServiceMultiplexSocketServer $MAIN_ARGS >$LOG_FILE 2>&1 &
	fi
	
	local server_pid=$!
	sleep 30
	
	ps v $server_pid >/dev/null
	if [ $? = 0 ] ; then
	    echo $server_pid > $AOMS_ENV_ROOT/scripts/pid
	    echo "##################################################################"
	    echo "# Successfully started Grid Engine server as process $server_pid"
	    echo "##################################################################"
	else
		echo "##################################################################"
	    echo " Failed to start Grid Engine"
	    echo "##################################################################"
	    exit 1
	fi
}

function _stop() {
	if [ -f $AOMS_ENV_ROOT/scripts/pid ]; then
		local pid=$(cat $AOMS_ENV_ROOT/scripts/pid)
		echo "##################################################################"
		echo "# Stop Grid Engine server..."
		echo "##################################################################"
		rm -f $AOMS_ENV_ROOT/scripts/pid
		kill $pid
		echo "##################################################################"
		echo "# Successfully stopped Grid Engine server"
		echo "##################################################################"		
	else
		local msg=$1
		if [[ $msg != "" ]]; then
			echo $msg
		fi
	fi
}

function _restart() {
	_stop
	_start
}

case $ACTION in
	start)		_start
				;;
	stop)		_stop "Grid Engine has not been started!"
				;;
	restart)	_restart
				;;
	*)			usage
  				exit 1
  				;;
esac
